@@ -17,8 +17,11 @@ Beacon that fires events on vm state changes
         - interval: 60
         - startup_create_event: True
 """
+
 import logging
 
+import salt.utils.beacons
+
 __virtualname__ = "vmadm"
 
 VMADM_STATE = {
@@ -36,12 +39,9 @@ def __virtual__():
     if "vmadm.list" in __salt__:
         return True
     else:
-        return (
-            False,
-            "{} beacon can only be loaded on SmartOS compute nodes".format(
-                __virtualname__
-            ),
-        )
+        err_msg = "Only available on SmartOS compute nodes."
+        log.error("Unable to load %s beacon: %s", __virtualname__, err_msg)
+        return False, err_msg
 
 
 def validate(config):
@@ -66,24 +66,24 @@ def beacon(config):
 
     # NOTE: lookup current images
     current_vms = __salt__["vmadm.list"](
-        keyed=True, order="uuid,state,alias,hostname,dns_domain",
+        keyed=True,
+        order="uuid,state,alias,hostname,dns_domain",
     )
 
     # NOTE: apply configuration
     if VMADM_STATE["first_run"]:
         log.info("Applying configuration for vmadm beacon")
 
-        _config = {}
-        list(map(_config.update, config))
+        config = salt.utils.beacons.list_to_dict(config)
 
-        if "startup_create_event" not in _config or not _config["startup_create_event"]:
+        if "startup_create_event" not in config or not config["startup_create_event"]:
             VMADM_STATE["vms"] = current_vms
 
     # NOTE: create events
     for uuid in current_vms:
         event = {}
         if uuid not in VMADM_STATE["vms"]:
-            event["tag"] = "created/{}".format(uuid)
+            event["tag"] = f"created/{uuid}"
             for label in current_vms[uuid]:
                 if label == "state":
                     continue
@@ -96,7 +96,7 @@ def beacon(config):
     for uuid in VMADM_STATE["vms"]:
         event = {}
         if uuid not in current_vms:
-            event["tag"] = "deleted/{}".format(uuid)
+            event["tag"] = f"deleted/{uuid}"
             for label in VMADM_STATE["vms"][uuid]:
                 if label == "state":
                     continue
@@ -133,6 +133,3 @@ def beacon(config):
         VMADM_STATE["first_run"] = False
 
     return ret
-
-
-# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
