@@ -17,6 +17,7 @@ import os.path
 import shutil
 import tempfile
 
+import salt.payload
 import salt.utils.atomicfile
 import salt.utils.files
 from salt.exceptions import SaltCacheError
@@ -50,20 +51,20 @@ def store(bank, key, data, cachedir):
     except OSError as exc:
         if exc.errno != errno.EEXIST:
             raise SaltCacheError(
-                "The cache directory, {}, could not be created: {}".format(base, exc)
+                f"The cache directory, {base}, could not be created: {exc}"
             )
 
-    outfile = os.path.join(base, "{}.p".format(key))
+    outfile = os.path.join(base, f"{key}.p")
     tmpfh, tmpfname = tempfile.mkstemp(dir=base)
     os.close(tmpfh)
     try:
         with salt.utils.files.fopen(tmpfname, "w+b") as fh_:
-            __context__["serial"].dump(data, fh_)
+            salt.payload.dump(data, fh_)
         # On Windows, os.rename will fail if the destination file exists.
         salt.utils.atomicfile.atomic_rename(tmpfname, outfile)
     except OSError as exc:
         raise SaltCacheError(
-            "There was an error writing the cache file, {}: {}".format(base, exc)
+            f"There was an error writing the cache file, {base}: {exc}"
         )
 
 
@@ -72,7 +73,7 @@ def fetch(bank, key, cachedir):
     Fetch information from a file.
     """
     inkey = False
-    key_file = os.path.join(cachedir, os.path.normpath(bank), "{}.p".format(key))
+    key_file = os.path.join(cachedir, os.path.normpath(bank), f"{key}.p")
     if not os.path.isfile(key_file):
         # The bank includes the full filename, and the key is inside the file
         key_file = os.path.join(cachedir, os.path.normpath(bank) + ".p")
@@ -84,12 +85,12 @@ def fetch(bank, key, cachedir):
     try:
         with salt.utils.files.fopen(key_file, "rb") as fh_:
             if inkey:
-                return __context__["serial"].load(fh_)[key]
+                return salt.payload.load(fh_)[key]
             else:
-                return __context__["serial"].load(fh_)
+                return salt.payload.load(fh_)
     except OSError as exc:
         raise SaltCacheError(
-            'There was an error reading the cache file "{}": {}'.format(key_file, exc)
+            f'There was an error reading the cache file "{key_file}": {exc}'
         )
 
 
@@ -97,7 +98,7 @@ def updated(bank, key, cachedir):
     """
     Return the epoch of the mtime for this cache file
     """
-    key_file = os.path.join(cachedir, os.path.normpath(bank), "{}.p".format(key))
+    key_file = os.path.join(cachedir, os.path.normpath(bank), f"{key}.p")
     if not os.path.isfile(key_file):
         log.warning('Cache file "%s" does not exist', key_file)
         return None
@@ -105,7 +106,7 @@ def updated(bank, key, cachedir):
         return int(os.path.getmtime(key_file))
     except OSError as exc:
         raise SaltCacheError(
-            'There was an error reading the mtime for "{}": {}'.format(key_file, exc)
+            f'There was an error reading the mtime for "{key_file}": {exc}'
         )
 
 
@@ -123,12 +124,12 @@ def flush(bank, key=None, cachedir=None):
                 return False
             shutil.rmtree(target)
         else:
-            target = os.path.join(cachedir, os.path.normpath(bank), "{}.p".format(key))
+            target = os.path.join(cachedir, os.path.normpath(bank), f"{key}.p")
             if not os.path.isfile(target):
                 return False
             os.remove(target)
     except OSError as exc:
-        raise SaltCacheError('There was an error removing "{}": {}'.format(target, exc))
+        raise SaltCacheError(f'There was an error removing "{target}": {exc}')
     return True
 
 
@@ -142,9 +143,7 @@ def list_(bank, cachedir):
     try:
         items = os.listdir(base)
     except OSError as exc:
-        raise SaltCacheError(
-            'There was an error accessing directory "{}": {}'.format(base, exc)
-        )
+        raise SaltCacheError(f'There was an error accessing directory "{base}": {exc}')
     ret = []
     for item in items:
         if item.endswith(".p"):
@@ -162,5 +161,5 @@ def contains(bank, key, cachedir):
         base = os.path.join(cachedir, os.path.normpath(bank))
         return os.path.isdir(base)
     else:
-        keyfile = os.path.join(cachedir, os.path.normpath(bank), "{}.p".format(key))
+        keyfile = os.path.join(cachedir, os.path.normpath(bank), f"{key}.p")
         return os.path.isfile(keyfile)
