@@ -2,27 +2,20 @@
 Make me some salt!
 """
 
-
+import logging
 import os
 import warnings
 
-# We import log ASAP because we NEED to make sure that any logger instance salt
-# instantiates is using salt.log.setup.SaltLoggingClass
-import salt.log.setup
 import salt.utils.kinds as kinds
 from salt.exceptions import SaltClientError, SaltSystemExit, get_error_message
-
-# the try block below bypasses an issue at build time so that modules don't
-# cause the build to fail
 from salt.utils import migrations
 from salt.utils.platform import is_junos
 from salt.utils.process import HAS_PSUTIL
-from salt.utils.verify import verify_log
 
 # All salt related deprecation warnings should be shown once each!
 warnings.filterwarnings(
     "once",  # Show once
-    "",  # No deprecation message matchHAS_PSUTIL
+    "",  # No deprecation message match
     DeprecationWarning,  # This filter is for DeprecationWarnings
     r"^(salt|salt\.(.*))$",  # Match module(s) 'salt' and 'salt.<whatever>'
     append=True,
@@ -39,24 +32,25 @@ warnings.filterwarnings(
 # Filter the backports package UserWarning about being re-imported
 warnings.filterwarnings(
     "ignore",
-    "^Module backports was already imported from (.*), but (.*) is being added to sys.path$",
+    "^Module backports was already imported from (.*), but (.*) is being added to"
+    " sys.path$",
     UserWarning,
     append=True,
 )
 
 
+# the try block below bypasses an issue at build time so that modules don't
+# cause the build to fail
 try:
     import salt.utils.parsers
+    from salt.utils.network import ip_bracket
     from salt.utils.verify import check_user, verify_env, verify_socket
-    from salt.utils.zeromq import ip_bracket
 except ImportError as exc:
     if exc.args[0] != "No module named _msgpack":
         raise
 
 
-# Let's instantiate log using salt.log.setup.logging.getLogger() so pylint
-# leaves us alone and stops complaining about an un-used import
-log = salt.log.setup.logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 
 class DaemonsMixin:  # pylint: disable=no-init
@@ -125,15 +119,57 @@ class Master(
     Creates a master server
     """
 
-    def _handle_signals(self, signum, sigframe):  # pylint: disable=unused-argument
+    def _handle_signals(self, signum, sigframe):
         if hasattr(self.master, "process_manager"):
             # escalate signal to the process manager processes
-            self.master.process_manager.stop_restarting()
-            self.master.process_manager.send_signal_to_processes(signum)
-            # kill any remaining processes
-            self.master.process_manager.kill_children()
+            self.master.process_manager._handle_signals(signum, sigframe)
         super()._handle_signals(signum, sigframe)
 
+    def verify_environment(self):
+        if not self.config["verify_env"]:
+            return
+        v_dirs = [
+            self.config["pki_dir"],
+            os.path.join(self.config["pki_dir"], "minions"),
+            os.path.join(self.config["pki_dir"], "minions_pre"),
+            os.path.join(self.config["pki_dir"], "minions_denied"),
+            os.path.join(self.config["pki_dir"], "minions_autosign"),
+            os.path.join(self.config["pki_dir"], "minions_rejected"),
+            self.config["cachedir"],
+            os.path.join(self.config["cachedir"], "jobs"),
+            os.path.join(self.config["cachedir"], "proc"),
+            self.config["sock_dir"],
+            self.config["token_dir"],
+            self.config["syndic_dir"],
+            self.config["sqlite_queue_dir"],
+        ]
+        pki_dir = self.config["pki_dir"]
+        if (
+            self.config["cluster_id"]
+            and self.config["cluster_pki_dir"]
+            and self.config["cluster_pki_dir"] != self.config["pki_dir"]
+        ):
+            v_dirs.extend(
+                [
+                    self.config["cluster_pki_dir"],
+                    os.path.join(self.config["cluster_pki_dir"], "peers"),
+                    os.path.join(self.config["cluster_pki_dir"], "minions"),
+                    os.path.join(self.config["cluster_pki_dir"], "minions_pre"),
+                    os.path.join(self.config["cluster_pki_dir"], "minions_denied"),
+                    os.path.join(self.config["cluster_pki_dir"], "minions_autosign"),
+                    os.path.join(self.config["cluster_pki_dir"], "minions_rejected"),
+                ]
+            )
+            pki_dir = [self.config["pki_dir"], self.config["cluster_pki_dir"]]
+
+        verify_env(
+            v_dirs,
+            self.config["user"],
+            permissive=self.config["permissive_pki_access"],
+            root_dir=self.config["root_dir"],
+            pki_dir=pki_dir,
+        )
+
     def prepare(self):
         """
         Run the preparation sequence required to start a salt master server.
@@ -145,37 +181,10 @@ class Master(
         super().prepare()
 
         try:
-            if self.config["verify_env"]:
-                v_dirs = [
-                    self.config["pki_dir"],
-                    os.path.join(self.config["pki_dir"], "minions"),
-                    os.path.join(self.config["pki_dir"], "minions_pre"),
-                    os.path.join(self.config["pki_dir"], "minions_denied"),
-                    os.path.join(self.config["pki_dir"], "minions_autosign"),
-                    os.path.join(self.config["pki_dir"], "minions_rejected"),
-                    self.config["cachedir"],
-                    os.path.join(self.config["cachedir"], "jobs"),
-                    os.path.join(self.config["cachedir"], "proc"),
-                    self.config["sock_dir"],
-                    self.config["token_dir"],
-                    self.config["syndic_dir"],
-                    self.config["sqlite_queue_dir"],
-                ]
-                verify_env(
-                    v_dirs,
-                    self.config["user"],
-                    permissive=self.config["permissive_pki_access"],
-                    root_dir=self.config["root_dir"],
-                    pki_dir=self.config["pki_dir"],
-                )
-                # Clear out syndics from cachedir
-                for syndic_file in os.listdir(self.config["syndic_dir"]):
-                    os.remove(os.path.join(self.config["syndic_dir"], syndic_file))
+            self.verify_environment()
         except OSError as error:
             self.environment_failure(error)
 
-        self.setup_logfile_logger()
-        verify_log(self.config)
         self.action_log_info("Setting up")
 
         # TODO: AIO core is separate from transport
@@ -288,8 +297,6 @@ class Minion(
         except OSError as error:
             self.environment_failure(error)
 
-        self.setup_logfile_logger()
-        verify_log(self.config)
         log.info('Setting up the Salt Minion "%s"', self.config["id"])
         migrations.migrate_paths(self.config)
 
@@ -302,8 +309,7 @@ class Minion(
 
         transport = self.config.get("transport").lower()
 
-        # TODO: AIO core is separate from transport
-        if transport in ("zeromq", "tcp", "detect"):
+        try:
             # Late import so logging works correctly
             import salt.minion
 
@@ -316,11 +322,9 @@ class Minion(
             if self.config.get("master_type") == "func":
                 salt.minion.eval_master_func(self.config)
             self.minion = salt.minion.MinionManager(self.config)
-        else:
+        except Exception:  # pylint: disable=broad-except
             log.error(
-                "The transport '%s' is not supported. Please use one of "
-                "the following: tcp, zeromq, or detect.",
-                transport,
+                "An error occured while setting up the minion manager", exc_info=True
             )
             self.shutdown(1)
 
@@ -484,8 +488,6 @@ class ProxyMinion(
         except OSError as error:
             self.environment_failure(error)
 
-        self.setup_logfile_logger()
-        verify_log(self.config)
         self.action_log_info('Setting up "{}"'.format(self.config["id"]))
 
         migrations.migrate_paths(self.config)
@@ -580,7 +582,6 @@ class Syndic(
                 verify_env(
                     [
                         self.config["pki_dir"],
-                        self.config["cachedir"],
                         self.config["sock_dir"],
                         self.config["extension_modules"],
                     ],
@@ -592,8 +593,6 @@ class Syndic(
         except OSError as error:
             self.environment_failure(error)
 
-        self.setup_logfile_logger()
-        verify_log(self.config)
         self.action_log_info('Setting up "{}"'.format(self.config["id"]))
 
         # Late import so logging works correctly
