@@ -92,7 +92,7 @@ class Shell:
         ssh_options=None,
     ):
         self.opts = opts
-        # ssh <ipv6>, but scp [<ipv6]:/path
+        # ssh <ipv6>, but scp [<ipv6>]:/path
         self.host = host.strip("[]")
         self.user = user
         self.port = port
@@ -132,6 +132,8 @@ class Shell:
             options.append("PasswordAuthentication=yes")
         else:
             options.append("PasswordAuthentication=no")
+        if self.opts.get("_ssh_version", (0,)) > (4, 9):
+            options.append("GSSAPIAuthentication=no")
         options.append(f"ConnectTimeout={self.timeout}")
         if self.opts.get("ignore_host_keys"):
             options.append("StrictHostKeyChecking=no")
@@ -165,6 +167,8 @@ class Shell:
             "ControlMaster=auto",
             "StrictHostKeyChecking=no",
         ]
+        if self.opts["_ssh_version"] > (4, 9):
+            options.append("GSSAPIAuthentication=no")
         options.append(f"ConnectTimeout={self.timeout}")
         if self.opts.get("ignore_host_keys"):
             options.append("StrictHostKeyChecking=no")
@@ -340,9 +344,17 @@ class Shell:
         scp a file or files to a remote system
         """
         if makedirs:
-            self.exec_cmd(f"mkdir -p {os.path.dirname(remote)}")
+            pardir = os.path.dirname(remote)
+            if not pardir:
+                log.warning(
+                    "Makedirs called on relative filename: '%s'. Skipping.", remote
+                )
+            else:
+                ret = self.exec_cmd("mkdir -p " + shlex.quote(pardir))
+                if ret[2]:
+                    return ret
 
-        # scp needs [<ipv6}
+        # scp needs [<ipv6>]
         host = self.host
         if ":" in host:
             host = f"[{host}]"
