@@ -2,9 +2,10 @@
 Send events from webhook api
 """
 
-import salt.ext.tornado.httpserver
-import salt.ext.tornado.ioloop
-import salt.ext.tornado.web
+import tornado.httpserver
+import tornado.ioloop
+import tornado.web
+
 import salt.utils.event
 
 
@@ -63,9 +64,7 @@ def start(address=None, port=5000, ssl_crt=None, ssl_key=None):
         else:
             __salt__["event.send"](tag, msg)
 
-    class WebHook(
-        salt.ext.tornado.web.RequestHandler
-    ):  # pylint: disable=abstract-method
+    class WebHook(tornado.web.RequestHandler):  # pylint: disable=abstract-method
         def post(self, tag):  # pylint: disable=arguments-differ
             body = self.request.body
             headers = self.request.headers
@@ -75,14 +74,11 @@ def start(address=None, port=5000, ssl_crt=None, ssl_key=None):
             }
             fire("salt/engines/hook/" + tag, payload)
 
-    application = salt.ext.tornado.web.Application([(r"/(.*)", WebHook)])
+    application = tornado.web.Application([(r"/(.*)", WebHook)])
     ssl_options = None
     if all([ssl_crt, ssl_key]):
         ssl_options = {"certfile": ssl_crt, "keyfile": ssl_key}
-    io_loop = salt.ext.tornado.ioloop.IOLoop(make_current=False)
-    io_loop.make_current()
-    http_server = salt.ext.tornado.httpserver.HTTPServer(
-        application, ssl_options=ssl_options
-    )
+    io_loop = tornado.ioloop.IOLoop()
+    http_server = tornado.httpserver.HTTPServer(application, ssl_options=ssl_options)
     http_server.listen(port, address=address)
     io_loop.start()
