@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Arista pyeapi
 =============
@@ -89,19 +88,13 @@ outside a ``pyeapi`` Proxy, e.g.:
     Minion. If you want to use the :mod:`pyeapi Proxy <salt.proxy.arista_pyeapi>`,
     please follow the documentation notes for a proper setup.
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import python stdlib
 import difflib
 import logging
 
 from salt.exceptions import CommandExecutionError
-
-# Import Salt libs
-from salt.ext import six
 from salt.utils.args import clean_kwargs
 
-# Import third party libs
 try:
     import pyeapi
 
@@ -148,7 +141,8 @@ def __virtual__():
     if not HAS_PYEAPI:
         return (
             False,
-            "The pyeapi execution module requires pyeapi library to be installed: ``pip install pyeapi``",
+            "The pyeapi execution module requires pyeapi library to be installed: ``pip"
+            " install pyeapi``",
         )
     return __virtualname__
 
@@ -404,7 +398,7 @@ def config(
     context=None,
     defaults=None,
     saltenv="base",
-    **kwargs
+    **kwargs,
 ):
     """
     Configures the node with the specified commands.
@@ -515,11 +509,11 @@ def config(
     if config_file:
         file_str = __salt__["cp.get_file_str"](config_file, saltenv=saltenv)
         if file_str is False:
-            raise CommandExecutionError("Source file {} not found".format(config_file))
+            raise CommandExecutionError(f"Source file {config_file} not found")
         log.debug("Fetched from %s", config_file)
         log.debug(file_str)
     elif commands:
-        if isinstance(commands, (six.string_types, six.text_type)):
+        if isinstance(commands, str):
             commands = [commands]
         file_str = "\n".join(commands)
         # unify all the commands in a single file, to render them in a go
