@@ -40,6 +40,7 @@ Connection module for Amazon ELB
 
 :depends: boto >= 2.33.0
 """
+
 # keep lint from choking on _get_conn and _cache_id
 # pylint: disable=E0602
 
@@ -54,10 +55,12 @@ try:
     import boto
     import boto.ec2  # pylint: enable=unused-import
     from boto.ec2.elb import HealthCheck
-    from boto.ec2.elb.attributes import AccessLogAttribute
-    from boto.ec2.elb.attributes import ConnectionDrainingAttribute
-    from boto.ec2.elb.attributes import ConnectionSettingAttribute
-    from boto.ec2.elb.attributes import CrossZoneLoadBalancingAttribute
+    from boto.ec2.elb.attributes import (
+        AccessLogAttribute,
+        ConnectionDrainingAttribute,
+        ConnectionSettingAttribute,
+        CrossZoneLoadBalancingAttribute,
+    )
 
     logging.getLogger("boto").setLevel(logging.CRITICAL)
     HAS_BOTO = True
@@ -192,6 +195,9 @@ def get_elb_config(name, region=None, key=None, keyid=None, profile=None):
             for policy_list in lb_policy_lists:
                 policies += [p.policy_name for p in policy_list]
             ret["policies"] = policies
+            ret["canonical_hosted_zone_name"] = lb.canonical_hosted_zone_name
+            ret["canonical_hosted_zone_name_id"] = lb.canonical_hosted_zone_name_id
+            ret["vpc_id"] = lb.vpc_id
             return ret
         except boto.exception.BotoServerError as error:
             if error.error_code == "Throttling":
@@ -1096,9 +1102,9 @@ def _build_tag_param_list(params, tags):
     i = 1
     for key in keys:
         value = tags[key]
-        params["Tags.member.{}.Key".format(i)] = key
+        params[f"Tags.member.{i}.Key"] = key
         if value is not None:
-            params["Tags.member.{}.Value".format(i)] = value
+            params[f"Tags.member.{i}.Value"] = value
         i += 1
 
 
