@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Common resources for LXC and systemd-nspawn containers
 
@@ -10,18 +9,14 @@ These functions are not designed to be called directly, but instead from the
 common logic to be re-used for common actions.
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import copy
 import functools
 import logging
 import os
-import pipes
+import shlex
 import time
 import traceback
 
-# Import salt libs
 import salt.utils.args
 import salt.utils.path
 import salt.utils.vt
@@ -29,7 +24,7 @@ from salt.exceptions import CommandExecutionError, SaltInvocationError
 
 log = logging.getLogger(__name__)
 
-PATH = "PATH=/bin:/usr/bin:/sbin:/usr/sbin:/opt/bin:" "/usr/local/bin:/usr/local/sbin"
+PATH = "PATH=/bin:/usr/bin:/sbin:/usr/sbin:/opt/bin:/usr/local/bin:/usr/local/sbin"
 
 
 def _validate(wrapped):
@@ -48,13 +43,13 @@ def _validate(wrapped):
         }
         if container_type not in valid_driver:
             raise SaltInvocationError(
-                "Invalid container type '{0}'. Valid types are: {1}".format(
+                "Invalid container type '{}'. Valid types are: {}".format(
                     container_type, ", ".join(sorted(valid_driver))
                 )
             )
         if exec_driver not in valid_driver[container_type]:
             raise SaltInvocationError(
-                "Invalid command execution driver. Valid drivers are: {0}".format(
+                "Invalid command execution driver. Valid drivers are: {}".format(
                     ", ".join(valid_driver[container_type])
                 )
             )
@@ -72,18 +67,16 @@ def _nsenter(pid):
     """
     Return the nsenter command to attach to the named container
     """
-    return "nsenter --target {0} --mount --uts --ipc --net --pid".format(pid)
+    return f"nsenter --target {pid} --mount --uts --ipc --net --pid"
 
 
-def _get_md5(name, path, run_func):
+def _get_sha256(name, path, run_func):
     """
-    Get the MD5 checksum of a file from a container
+    Get the sha256 checksum of a file from a container
     """
-    output = run_func(
-        name, "md5sum {0}".format(pipes.quote(path)), ignore_retcode=True
-    )["stdout"]
+    ret = run_func(name, f"sha256sum {shlex.quote(path)}", ignore_retcode=True)
     try:
-        return output.split()[0]
+        return ret["stdout"].split()[0]
     except IndexError:
         # Destination file does not exist or could not be accessed
         return None
@@ -106,10 +99,10 @@ def cache_file(source):
         if source.startswith("salt://"):
             cached_source = __salt__["cp.cache_file"](source)
             if not cached_source:
-                raise CommandExecutionError("Unable to cache {0}".format(source))
+                raise CommandExecutionError(f"Unable to cache {source}")
             return cached_source
     except AttributeError:
-        raise SaltInvocationError("Invalid source file {0}".format(source))
+        raise SaltInvocationError(f"Invalid source file {source}")
     return source
 
 
@@ -147,7 +140,7 @@ def run(
         cmd_func = "cmd.run"
     elif output not in valid_output:
         raise SaltInvocationError(
-            "'output' param must be one of the following: {0}".format(
+            "'output' param must be one of the following: {}".format(
                 ", ".join(valid_output)
             )
         )
@@ -168,57 +161,47 @@ def run(
     if exec_driver == "lxc-attach":
         full_cmd = "lxc-attach "
         if path:
-            full_cmd += "-P {0} ".format(pipes.quote(path))
+            full_cmd += f"-P {shlex.quote(path)} "
         if keep_env is not True:
             full_cmd += "--clear-env "
             if "PATH" not in to_keep:
-                full_cmd += "--set-var {0} ".format(PATH)
+                full_cmd += f"--set-var {PATH} "
                 # --clear-env results in a very restrictive PATH
                 # (/bin:/usr/bin), use a good fallback.
         full_cmd += " ".join(
             [
-                "--set-var {0}={1}".format(x, pipes.quote(os.environ[x]))
+                f"--set-var {x}={shlex.quote(os.environ[x])}"
                 for x in to_keep
                 if x in os.environ
             ]
         )
-        full_cmd += " -n {0} -- {1}".format(pipes.quote(name), cmd)
+        full_cmd += f" -n {shlex.quote(name)} -- {cmd}"
     elif exec_driver == "nsenter":
-        pid = __salt__["{0}.pid".format(container_type)](name)
-        full_cmd = "nsenter --target {0} --mount --uts --ipc --net --pid -- ".format(
-            pid
-        )
+        pid = __salt__[f"{container_type}.pid"](name)
+        full_cmd = f"nsenter --target {pid} --mount --uts --ipc --net --pid -- "
         if keep_env is not True:
             full_cmd += "env -i "
             if "PATH" not in to_keep:
-                full_cmd += "{0} ".format(PATH)
+                full_cmd += f"{PATH} "
         full_cmd += " ".join(
-            [
-                "{0}={1}".format(x, pipes.quote(os.environ[x]))
-                for x in to_keep
-                if x in os.environ
-            ]
+            [f"{x}={shlex.quote(os.environ[x])}" for x in to_keep if x in os.environ]
         )
-        full_cmd += " {0}".format(cmd)
+        full_cmd += f" {cmd}"
     elif exec_driver == "docker-exec":
         # We're using docker exec on the CLI as opposed to via docker-py, since
         # the Docker API doesn't return stdout and stderr separately.
         full_cmd = "docker exec "
         if stdin:
             full_cmd += "-i "
-        full_cmd += "{0} ".format(name)
+        full_cmd += f"{name} "
         if keep_env is not True:
             full_cmd += "env -i "
             if "PATH" not in to_keep:
-                full_cmd += "{0} ".format(PATH)
+                full_cmd += f"{PATH} "
         full_cmd += " ".join(
-            [
-                "{0}={1}".format(x, pipes.quote(os.environ[x]))
-                for x in to_keep
-                if x in os.environ
-            ]
+            [f"{x}={shlex.quote(os.environ[x])}" for x in to_keep if x in os.environ]
         )
-        full_cmd += " {0}".format(cmd)
+        full_cmd += f" {cmd}"
 
     if not use_vt:
         ret = __salt__[cmd_func](
@@ -305,13 +288,13 @@ def copy_to(
         salt myminion container_resource.copy_to mycontainer /local/file/path /container/file/path container_type=docker exec_driver=nsenter
     """
     # Get the appropriate functions
-    state = __salt__["{0}.state".format(container_type)]
+    state = __salt__[f"{container_type}.state"]
 
     def run_all(*args, **akwargs):
         akwargs = copy.deepcopy(akwargs)
         if container_type in ["lxc"] and "path" not in akwargs:
             akwargs["path"] = path
-        return __salt__["{0}.run_all".format(container_type)](*args, **akwargs)
+        return __salt__[f"{container_type}.run_all"](*args, **akwargs)
 
     state_kwargs = {}
     cmd_kwargs = {"ignore_retcode": True}
@@ -327,7 +310,7 @@ def copy_to(
 
     c_state = _state(name)
     if c_state != "running":
-        raise CommandExecutionError("Container '{0}' is not running".format(name))
+        raise CommandExecutionError(f"Container '{name}' is not running")
 
     local_file = cache_file(source)
     source_dir, source_name = os.path.split(local_file)
@@ -336,17 +319,14 @@ def copy_to(
     if not os.path.isabs(local_file):
         raise SaltInvocationError("Source path must be absolute")
     elif not os.path.exists(local_file):
-        raise SaltInvocationError("Source file {0} does not exist".format(local_file))
+        raise SaltInvocationError(f"Source file {local_file} does not exist")
     elif not os.path.isfile(local_file):
         raise SaltInvocationError("Source must be a regular file")
 
     # Destination file sanity checks
     if not os.path.isabs(dest):
         raise SaltInvocationError("Destination path must be absolute")
-    if (
-        run_all(name, "test -d {0}".format(pipes.quote(dest)), **cmd_kwargs)["retcode"]
-        == 0
-    ):
+    if run_all(name, f"test -d {shlex.quote(dest)}", **cmd_kwargs)["retcode"] == 0:
         # Destination is a directory, full path to dest file will include the
         # basename of the source file.
         dest = os.path.join(dest, source_name)
@@ -356,44 +336,39 @@ def copy_to(
         # parent directory.
         dest_dir, dest_name = os.path.split(dest)
         if (
-            run_all(name, "test -d {0}".format(pipes.quote(dest_dir)), **cmd_kwargs)[
-                "retcode"
-            ]
+            run_all(name, f"test -d {shlex.quote(dest_dir)}", **cmd_kwargs)["retcode"]
             != 0
         ):
             if makedirs:
                 result = run_all(
-                    name, "mkdir -p {0}".format(pipes.quote(dest_dir)), **cmd_kwargs
+                    name, f"mkdir -p {shlex.quote(dest_dir)}", **cmd_kwargs
                 )
                 if result["retcode"] != 0:
                     error = (
-                        "Unable to create destination directory {0} in "
-                        "container '{1}'".format(dest_dir, name)
+                        "Unable to create destination directory {} in "
+                        "container '{}'".format(dest_dir, name)
                     )
                     if result["stderr"]:
-                        error += ": {0}".format(result["stderr"])
+                        error += ": {}".format(result["stderr"])
                     raise CommandExecutionError(error)
             else:
                 raise SaltInvocationError(
-                    "Directory {0} does not exist on {1} container '{2}'".format(
+                    "Directory {} does not exist on {} container '{}'".format(
                         dest_dir, container_type, name
                     )
                 )
     if (
         not overwrite
-        and run_all(name, "test -e {0}".format(pipes.quote(dest)), **cmd_kwargs)[
-            "retcode"
-        ]
-        == 0
+        and run_all(name, f"test -e {shlex.quote(dest)}", **cmd_kwargs)["retcode"] == 0
     ):
         raise CommandExecutionError(
-            "Destination path {0} already exists. Use overwrite=True to "
+            "Destination path {} already exists. Use overwrite=True to "
             "overwrite it".format(dest)
         )
 
     # Before we try to replace the file, compare checksums.
-    source_md5 = __salt__["file.get_sum"](local_file, "md5")
-    if source_md5 == _get_md5(name, dest, run_all):
+    source_sha256 = __salt__["file.get_sum"](local_file, "sha256")
+    if source_sha256 == _get_sha256(name, dest, run_all):
         log.debug("%s and %s:%s are the same file, skipping copy", source, name, dest)
         return True
 
@@ -407,19 +382,20 @@ def copy_to(
     if exec_driver == "lxc-attach":
         lxcattach = "lxc-attach"
         if path:
-            lxcattach += " -P {0}".format(pipes.quote(path))
+            lxcattach += f" -P {shlex.quote(path)}"
         copy_cmd = (
-            'cat "{0}" | {4} --clear-env --set-var {1} -n {2} -- '
-            'tee "{3}"'.format(local_file, PATH, name, dest, lxcattach)
+            'cat "{0}" | {4} --clear-env --set-var {1} -n {2} -- tee "{3}"'.format(
+                local_file, PATH, name, dest, lxcattach
+            )
         )
     elif exec_driver == "nsenter":
-        pid = __salt__["{0}.pid".format(container_type)](name)
-        copy_cmd = 'cat "{0}" | {1} env -i {2} tee "{3}"'.format(
+        pid = __salt__[f"{container_type}.pid"](name)
+        copy_cmd = 'cat "{}" | {} env -i {} tee "{}"'.format(
             local_file, _nsenter(pid), PATH, dest
         )
     elif exec_driver == "docker-exec":
-        copy_cmd = 'cat "{0}" | docker exec -i {1} env -i {2} tee "{3}"'.format(
+        copy_cmd = 'cat "{}" | docker exec -i {} env -i {} tee "{}"'.format(
             local_file, name, PATH, dest
         )
     __salt__["cmd.run"](copy_cmd, python_shell=True, output_loglevel="quiet")
-    return source_md5 == _get_md5(name, dest, run_all)
+    return source_sha256 == _get_sha256(name, dest, run_all)
