@@ -2,7 +2,6 @@
 Resources needed by pkg providers
 """
 
-
 import copy
 import fnmatch
 import logging
@@ -26,12 +25,25 @@ def _repack_pkgs(pkgs, normalize=True):
     if normalize and "pkg.normalize_name" in __salt__:
         _normalize_name = __salt__["pkg.normalize_name"]
     else:
-        _normalize_name = lambda pkgname: pkgname
-    return {
+
+        def _normalize_name(pkgname):
+            return pkgname
+
+    repacked_pkgs = {
         _normalize_name(str(x)): str(y) if y is not None else y
         for x, y in salt.utils.data.repack_dictlist(pkgs).items()
     }
 
+    # Check if there were collisions in names
+    if len(pkgs) != len(repacked_pkgs):
+        raise SaltInvocationError(
+            "You are passing a list of packages that contains duplicated packages names: {}. This cannot be processed. In case you are targeting different versions of the same package, please target them individually".format(
+                pkgs
+            )
+        )
+
+    return repacked_pkgs
+
 
 def pack_sources(sources, normalize=True):
     """
@@ -60,7 +72,9 @@ def pack_sources(sources, normalize=True):
     if normalize and "pkg.normalize_name" in __salt__:
         _normalize_name = __salt__["pkg.normalize_name"]
     else:
-        _normalize_name = lambda pkgname: pkgname
+
+        def _normalize_name(pkgname):
+            return pkgname
 
     if isinstance(sources, str):
         try:
@@ -119,7 +133,7 @@ def parse_targets(
     elif pkgs:
         if version is not None:
             log.warning(
-                "'version' argument will be ignored for multiple " "package targets"
+                "'version' argument will be ignored for multiple package targets"
             )
         pkgs = _repack_pkgs(pkgs, normalize=normalize)
         if not pkgs:
@@ -130,7 +144,7 @@ def parse_targets(
     elif sources and __grains__["os"] != "MacOS":
         if version is not None:
             log.warning(
-                "'version' argument will be ignored for multiple " "package targets"
+                "'version' argument will be ignored for multiple package targets"
             )
         sources = pack_sources(sources, normalize=normalize)
         if not sources:
@@ -184,7 +198,7 @@ def version(*names, **kwargs):
     ret = {}
     versions_as_list = salt.utils.data.is_true(kwargs.pop("versions_as_list", False))
     pkg_glob = False
-    if len(names) != 0:
+    if names:
         pkgs = __salt__["pkg.list_pkgs"](versions_as_list=True, **kwargs)
         for name in names:
             if "*" in name:
@@ -399,7 +413,7 @@ def format_version(epoch, version, release):
     """
     Formats a version string for list_pkgs.
     """
-    full_version = "{}:{}".format(epoch, version) if epoch else version
+    full_version = f"{epoch}:{version}" if epoch else version
     if release:
-        full_version += "-{}".format(release)
+        full_version += f"-{release}"
     return full_version
