@@ -15,6 +15,7 @@ Module for retrieving random information from Random.org
           api_key: 7be1402d-5719-5bd3-a306-3def9f135da5
           api_version: 1
 """
+
 import http.client
 import logging
 import urllib.request
@@ -205,7 +206,7 @@ def generateIntegers(api_key=None, api_version=None, **kwargs):
     for item in ["number", "minimum", "maximum"]:
         if item not in kwargs:
             ret["res"] = False
-            ret["message"] = "Rquired argument, {} is missing.".format(item)
+            ret["message"] = f"Rquired argument, {item} is missing."
             return ret
 
     if not _numeric(kwargs["number"]) or not 1 <= kwargs["number"] <= 10000:
@@ -218,9 +219,9 @@ def generateIntegers(api_key=None, api_version=None, **kwargs):
         or not -1000000000 <= kwargs["minimum"] <= 1000000000
     ):
         ret["res"] = False
-        ret[
-            "message"
-        ] = "Minimum argument must be between -1,000,000,000 and 1,000,000,000"
+        ret["message"] = (
+            "Minimum argument must be between -1,000,000,000 and 1,000,000,000"
+        )
         return ret
 
     if (
@@ -228,9 +229,9 @@ def generateIntegers(api_key=None, api_version=None, **kwargs):
         or not -1000000000 <= kwargs["maximum"] <= 1000000000
     ):
         ret["res"] = False
-        ret[
-            "message"
-        ] = "Maximum argument must be between -1,000,000,000 and 1,000,000,000"
+        ret["message"] = (
+            "Maximum argument must be between -1,000,000,000 and 1,000,000,000"
+        )
         return ret
 
     if "base" in kwargs:
@@ -331,7 +332,7 @@ def generateStrings(api_key=None, api_version=None, **kwargs):
     for item in ["number", "length", "characters"]:
         if item not in kwargs:
             ret["res"] = False
-            ret["message"] = "Required argument, {} is missing.".format(item)
+            ret["message"] = f"Required argument, {item} is missing."
             return ret
 
     if not _numeric(kwargs["number"]) or not 1 <= kwargs["number"] <= 10000:
@@ -421,7 +422,7 @@ def generateUUIDs(api_key=None, api_version=None, **kwargs):
     for item in ["number"]:
         if item not in kwargs:
             ret["res"] = False
-            ret["message"] = "Required argument, {} is missing.".format(item)
+            ret["message"] = f"Required argument, {item} is missing."
             return ret
 
     if isinstance(api_version, int):
@@ -502,7 +503,7 @@ def generateDecimalFractions(api_key=None, api_version=None, **kwargs):
     for item in ["number", "decimalPlaces"]:
         if item not in kwargs:
             ret["res"] = False
-            ret["message"] = "Required argument, {} is missing.".format(item)
+            ret["message"] = f"Required argument, {item} is missing."
             return ret
 
     if not isinstance(kwargs["number"], int) or not 1 <= kwargs["number"] <= 10000:
@@ -596,7 +597,7 @@ def generateGaussians(api_key=None, api_version=None, **kwargs):
     for item in ["number", "mean", "standardDeviation", "significantDigits"]:
         if item not in kwargs:
             ret["res"] = False
-            ret["message"] = "Required argument, {} is missing.".format(item)
+            ret["message"] = f"Required argument, {item} is missing."
             return ret
 
     if not _numeric(kwargs["number"]) or not 1 <= kwargs["number"] <= 10000:
@@ -614,9 +615,9 @@ def generateGaussians(api_key=None, api_version=None, **kwargs):
         or not -1000000 <= kwargs["standardDeviation"] <= 1000000
     ):
         ret["res"] = False
-        ret[
-            "message"
-        ] = "The distribution's standard deviation must be between -1000000 and 1000000"
+        ret["message"] = (
+            "The distribution's standard deviation must be between -1000000 and 1000000"
+        )
         return ret
 
     if (
@@ -696,7 +697,7 @@ def generateBlobs(api_key=None, api_version=None, **kwargs):
     for item in ["number", "size"]:
         if item not in kwargs:
             ret["res"] = False
-            ret["message"] = "Required argument, {} is missing.".format(item)
+            ret["message"] = f"Required argument, {item} is missing."
             return ret
 
     if not _numeric(kwargs["number"]) or not 1 <= kwargs["number"] <= 100:
