@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Module for solrcloud configuration
 
@@ -6,16 +5,12 @@ Module for solrcloud configuration
 
 For now, module is limited to http-exposed API. It doesn't implement config upload via Solr zkCli
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import python libs
 import logging
 
 import salt.utils.http as http
 from salt.exceptions import SaltInvocationError
-from salt.ext import six
 
-# Import salt libs
 log = logging.getLogger(__name__)
 
 """
@@ -83,7 +78,7 @@ def _query(url, solr_url="http://localhost:8983/solr/", **kwargs):
 
     """
 
-    if not isinstance(solr_url, six.string_types):
+    if not isinstance(solr_url, str):
         raise ValueError("solr_url must be a string")
 
     if solr_url[-1:] != "/":
@@ -95,14 +90,13 @@ def _query(url, solr_url="http://localhost:8983/solr/", **kwargs):
     if "error" in query_result:
         if query_result["status"] == 404:
             raise SaltInvocationError(
-                "Got a 404 when trying to contact solr at {solr_url}{url}. Please check your solr URL.".format(
-                    solr_url=solr_url, url=url
-                )
+                "Got a 404 when trying to contact solr at {solr_url}{url}. Please check"
+                " your solr URL.".format(solr_url=solr_url, url=url)
             )
         else:
             raise SaltInvocationError(
                 "Got a {status} error when calling {solr_url}{url} : {error}".format(
-                    status=six.text_type(query_result["status"]),
+                    status=str(query_result["status"]),
                     solr_url=solr_url,
                     url=url,
                     error=query_result["error"],
@@ -121,7 +115,7 @@ def _validate_core_properties(properties):
 
     props_string = ""
 
-    for prop_name, prop_value in six.iteritems(properties):
+    for prop_name, prop_value in properties.items():
         if prop_name in BOOL_PROPS_LIST:
             if not isinstance(prop_value, bool):
                 raise ValueError('Option "' + prop_name + '" value must be an boolean')
@@ -134,7 +128,7 @@ def _validate_core_properties(properties):
                 + ("true" if prop_value else "false")
             )
         elif prop_name in STRING_PROPS_LIST:
-            if not isinstance(prop_value, six.string_types):
+            if not isinstance(prop_value, str):
                 raise ValueError(
                     'In option "properties", core property "'
                     + prop_name
@@ -145,11 +139,7 @@ def _validate_core_properties(properties):
 
         else:
             props_string = (
-                props_string
-                + "&property."
-                + six.text_type(prop_name)
-                + "="
-                + six.text_type(prop_value)
+                props_string + "&property." + str(prop_name) + "=" + str(prop_value)
             )
 
     return props_string
@@ -164,19 +154,19 @@ def _validate_collection_options(options):
 
     options_string = ""
 
-    for option_name, option_value in six.iteritems(options):
+    for option_name, option_value in options.items():
         if option_name in STRING_OPTIONS_LIST:
-            if not isinstance(option_value, six.string_types):
+            if not isinstance(option_value, str):
                 raise ValueError('Option "' + option_name + '" value must be a string')
 
             options_string = options_string + "&" + option_name + "=" + option_value
 
         elif option_name in INT_OPTIONS_LIST:
-            if not isinstance(option_value, six.integer_types):
+            if not isinstance(option_value, int):
                 raise ValueError('Option "' + option_name + '" value must be an int')
 
             options_string = (
-                options_string + "&" + option_name + "=" + six.text_type(option_value)
+                options_string + "&" + option_name + "=" + str(option_value)
             )
 
         elif option_name in BOOL_OPTIONS_LIST:
@@ -200,7 +190,7 @@ def _validate_collection_options(options):
                 )
 
             options_string = (
-                options_string + "&" + option_name + "=" + (", ".join(option_value))
+                options_string + "&" + option_name + "=" + ", ".join(option_value)
             )
 
         elif option_name in DICT_OPTIONS_LIST:
@@ -260,7 +250,7 @@ def alias_exists(alias_name, **kwargs):
         salt '*' solrcloud.alias_exists my_alias
     """
 
-    if not isinstance(alias_name, six.string_types):
+    if not isinstance(alias_name, str):
         raise ValueError("Alias name must be a string")
 
     cluster = cluster_status(**kwargs)
@@ -282,12 +272,12 @@ def alias_get_collections(alias_name, **kwargs):
         salt '*' solrcloud.alias_get my_alias
     """
 
-    if not isinstance(alias_name, six.string_types):
+    if not isinstance(alias_name, str):
         raise ValueError("Alias name must be a string")
 
     collection_aliases = [
         (k_v[0], k_v[1]["aliases"])
-        for k_v in six.iteritems(cluster_status(**kwargs)["collections"])
+        for k_v in cluster_status(**kwargs)["collections"].items()
         if "aliases" in k_v[1]
     ]
     aliases = [
@@ -317,14 +307,14 @@ def alias_set_collections(alias_name, collections=None, **kwargs):
         )
 
     for collection in collections:
-        if not isinstance(collection, six.string_types):
+        if not isinstance(collection, str):
             raise ValueError("Collection name must be a string")
 
     return _query(
         "admin/collections?action=CREATEALIAS&name={alias}&wt=json&collections={collections}".format(
             alias=alias_name, collections=", ".join(collections)
         ),
-        **kwargs
+        **kwargs,
     )
 
 
@@ -347,7 +337,7 @@ def collection_reload(collection, **kwargs):
         "admin/collections?action=RELOAD&name={collection}&wt=json".format(
             collection=collection
         ),
-        **kwargs
+        **kwargs,
     )
 
 
@@ -384,7 +374,7 @@ def collection_exists(collection_name, **kwargs):
 
     """
 
-    if not isinstance(collection_name, six.string_types):
+    if not isinstance(collection_name, str):
         raise ValueError("Collection name must be a string")
 
     return collection_name in collection_list(**kwargs)
@@ -408,7 +398,7 @@ def collection_backup(collection_name, location, backup_name=None, **kwargs):
         raise ValueError("Collection doesn't exists")
 
     if backup_name is not None:
-        backup_name = "&name={0}".format(backup_name)
+        backup_name = f"&name={backup_name}"
     else:
         backup_name = ""
 
@@ -416,7 +406,7 @@ def collection_backup(collection_name, location, backup_name=None, **kwargs):
         "{collection}/replication?command=BACKUP&location={location}{backup_name}&wt=json".format(
             collection=collection_name, backup_name=backup_name, location=location
         ),
-        **kwargs
+        **kwargs,
     )
 
 
@@ -446,7 +436,7 @@ def collection_backup_all(location, backup_name=None, **kwargs):
             "{collection}/replication?command=BACKUP&location={location}{backup_name}&wt=json".format(
                 collection=collection_name, backup_name=backup_name, location=location
             ),
-            **kwargs
+            **kwargs,
         )
 
 
@@ -491,7 +481,7 @@ def collection_create(collection_name, options=None, **kwargs):
         "admin/collections?action=CREATE&wt=json&name="
         + collection_name
         + options_string,
-        **kwargs
+        **kwargs,
     )
 
 
@@ -576,5 +566,5 @@ def collection_set_options(collection_name, options, **kwargs):
         "admin/collections?action=MODIFYCOLLECTION&wt=json&collection="
         + collection_name
         + options_string,
-        **kwargs
+        **kwargs,
     )
