@@ -4,7 +4,6 @@ Manage DACLs on Windows
 :depends:   - winreg Python module
 """
 
-
 import logging
 import os
 import re
@@ -330,7 +329,7 @@ class daclConstants:
         return path
 
 
-def _getUserSid(user):
+def _get_user_sid(user):
     """
     return a state error dictionary, with 'sid' as a field if it could be returned
     if user is None, sid will also be None
@@ -414,7 +413,7 @@ def get(path, objectType, user=None):
     """
     ret = {"Path": path, "ACLs": []}
 
-    sidRet = _getUserSid(user)
+    sidRet = _get_user_sid(user)
 
     if path and objectType:
         dc = daclConstants()
@@ -459,7 +458,7 @@ def add_ace(path, objectType, user, permission, acetype, propagation):
         acetype = acetype.strip().upper()
         propagation = propagation.strip().upper()
 
-        sidRet = _getUserSid(user)
+        sidRet = _get_user_sid(user)
         if not sidRet["result"]:
             return sidRet
         permissionbit = dc.getPermissionBit(objectTypeBit, permission)
@@ -503,17 +502,17 @@ def add_ace(path, objectType, user, permission, acetype, propagation):
                 )
                 ret["result"] = True
             except Exception as e:  # pylint: disable=broad-except
-                ret[
-                    "comment"
-                ] = "An error occurred attempting to add the ace.  The error was {}".format(
-                    e
+                ret["comment"] = (
+                    "An error occurred attempting to add the ace.  The error was {}".format(
+                        e
+                    )
                 )
                 ret["result"] = False
                 return ret
             if acesAdded:
                 ret["changes"]["Added ACEs"] = acesAdded
         else:
-            ret["comment"] = "Unable to obtain the DACL of {}".format(path)
+            ret["comment"] = f"Unable to obtain the DACL of {path}"
     else:
         ret["comment"] = "An empty value was specified for a required item."
         ret["result"] = False
@@ -556,7 +555,7 @@ def rm_ace(path, objectType, user, permission=None, acetype=None, propagation=No
         if check_ace(path, objectType, user, permission, acetype, propagation, True)[
             "Exists"
         ]:
-            sidRet = _getUserSid(user)
+            sidRet = _get_user_sid(user)
             if not sidRet["result"]:
                 return sidRet
             permissionbit = (
@@ -604,7 +603,7 @@ def rm_ace(path, objectType, user, permission=None, acetype=None, propagation=No
                     ret["result"] = True
                 except Exception as e:  # pylint: disable=broad-except
                     ret["result"] = False
-                    ret["comment"] = "Error removing ACE.  The error was {}.".format(e)
+                    ret["comment"] = f"Error removing ACE.  The error was {e}."
                     return ret
         else:
             ret["comment"] = "The specified ACE was not found on the path."
@@ -620,9 +619,9 @@ def _ace_to_text(ace, objectType):
     try:
         userSid = win32security.LookupAccountSid("", ace[2])
         if userSid[1]:
-            userSid = "{1}\\{0}".format(userSid[0], userSid[1])
+            userSid = f"{userSid[1]}\\{userSid[0]}"
         else:
-            userSid = "{}".format(userSid[0])
+            userSid = f"{userSid[0]}"
     except Exception:  # pylint: disable=broad-except
         userSid = win32security.ConvertSidToStringSid(ace[2])
     tPerm = ace[1]
@@ -644,7 +643,7 @@ def _ace_to_text(ace, objectType):
         if dc.validPropagations[objectType][x]["BITS"] == tProps:
             tProps = dc.validPropagations[objectType][x]["TEXT"]
             break
-    return "{} {} {} on {} {}".format(userSid, tAceType, tPerm, tProps, tInherited)
+    return f"{userSid} {tAceType} {tPerm} on {tProps} {tInherited}"
 
 
 def _set_dacl_inheritance(path, objectType, inheritance=True, copy=True, clear=False):
@@ -730,9 +729,9 @@ def _set_dacl_inheritance(path, objectType, inheritance=True, copy=True, clear=F
             ret["result"] = True
         except Exception as e:  # pylint: disable=broad-except
             ret["result"] = False
-            ret[
-                "comment"
-            ] = "Error attempting to set the inheritance.  The error was {}.".format(e)
+            ret["comment"] = (
+                f"Error attempting to set the inheritance.  The error was {e}."
+            )
 
     return ret
 
@@ -805,7 +804,7 @@ def check_inheritance(path, objectType, user=None):
 
     ret = {"result": False, "Inheritance": False, "comment": ""}
 
-    sidRet = _getUserSid(user)
+    sidRet = _get_user_sid(user)
 
     dc = daclConstants()
     objectType = dc.getObjectTypeBit(objectType)
@@ -818,9 +817,9 @@ def check_inheritance(path, objectType, user=None):
         dacls = sd.GetSecurityDescriptorDacl()
     except Exception as e:  # pylint: disable=broad-except
         ret["result"] = False
-        ret[
-            "comment"
-        ] = "Error obtaining the Security Descriptor or DACL of the path: {}.".format(e)
+        ret["comment"] = (
+            f"Error obtaining the Security Descriptor or DACL of the path: {e}."
+        )
         return ret
 
     for counter in range(0, dacls.GetAceCount()):
@@ -881,7 +880,7 @@ def check_ace(
         dc.getPropagationBit(objectTypeBit, propagation) if propagation else None
     )
 
-    sidRet = _getUserSid(user)
+    sidRet = _get_user_sid(user)
     if not sidRet["result"]:
         return sidRet
 
