@@ -12,6 +12,7 @@ import errno
 import logging
 import os
 import os.path
+import pathlib
 import stat
 import sys
 import tempfile
@@ -26,6 +27,7 @@ from salt.modules.file import (
     _add_flags,
     _assert_occurrence,
     _binary_replace,
+    _check_sig,
     _error,
     _get_bkroot,
     _get_eol,
@@ -125,6 +127,7 @@ if salt.utils.platform.is_windows():
         search = namespaced_function(search, globals())
         _get_flags = namespaced_function(_get_flags, globals())
         _binary_replace = namespaced_function(_binary_replace, globals())
+        _check_sig = namespaced_function(_check_sig, globals())
         _splitlines_preserving_trailing_newline = namespaced_function(
             _splitlines_preserving_trailing_newline, globals()
         )
@@ -272,7 +275,7 @@ def gid_to_group(gid):
 
         salt '*' file.gid_to_group S-1-5-21-626487655-2533044672-482107328-1010
     """
-    func_name = "{}.gid_to_group".format(__virtualname__)
+    func_name = f"{__virtualname__}.gid_to_group"
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -307,7 +310,7 @@ def group_to_gid(group):
 
         salt '*' file.group_to_gid administrators
     """
-    func_name = "{}.group_to_gid".format(__virtualname__)
+    func_name = f"{__virtualname__}.group_to_gid"
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -349,7 +352,7 @@ def get_pgid(path, follow_symlinks=True):
         salt '*' file.get_pgid c:\\temp\\test.txt
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {}".format(path))
+        raise CommandExecutionError(f"Path not found: {path}")
 
     # Under Windows, if the path is a symlink, the user that owns the symlink is
     # returned, not the user that owns the file/directory the symlink is
@@ -433,7 +436,7 @@ def get_gid(path, follow_symlinks=True):
 
         salt '*' file.get_gid c:\\temp\\test.txt
     """
-    func_name = "{}.get_gid".format(__virtualname__)
+    func_name = f"{__virtualname__}.get_gid"
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -480,7 +483,7 @@ def get_group(path, follow_symlinks=True):
 
         salt '*' file.get_group c:\\temp\\test.txt
     """
-    func_name = "{}.get_group".format(__virtualname__)
+    func_name = f"{__virtualname__}.get_group"
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -561,7 +564,7 @@ def get_uid(path, follow_symlinks=True):
         salt '*' file.get_uid c:\\temp\\test.txt follow_symlinks=False
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {}".format(path))
+        raise CommandExecutionError(f"Path not found: {path}")
 
     # Under Windows, if the path is a symlink, the user that owns the symlink is
     # returned, not the user that owns the file/directory the symlink is
@@ -600,7 +603,7 @@ def get_user(path, follow_symlinks=True):
         salt '*' file.get_user c:\\temp\\test.txt follow_symlinks=False
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {}".format(path))
+        raise CommandExecutionError(f"Path not found: {path}")
 
     # Under Windows, if the path is a symlink, the user that owns the symlink is
     # returned, not the user that owns the file/directory the symlink is
@@ -633,9 +636,9 @@ def get_mode(path):
         salt '*' file.get_mode /etc/passwd
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {}".format(path))
+        raise CommandExecutionError(f"Path not found: {path}")
 
-    func_name = "{}.get_mode".format(__virtualname__)
+    func_name = f"{__virtualname__}.get_mode"
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -684,7 +687,7 @@ def lchown(path, user, group=None, pgroup=None):
         salt '*' file.lchown c:\\temp\\test.txt myusername "pgroup='None'"
     """
     if group:
-        func_name = "{}.lchown".format(__virtualname__)
+        func_name = f"{__virtualname__}.lchown"
         if __opts__.get("fun", "") == func_name:
             log.info(
                 "The group parameter has no effect when using %s on "
@@ -733,7 +736,7 @@ def chown(path, user, group=None, pgroup=None, follow_symlinks=True):
     """
     # the group parameter is not used; only provided for API compatibility
     if group is not None:
-        func_name = "{}.chown".format(__virtualname__)
+        func_name = f"{__virtualname__}.chown"
         if __opts__.get("fun", "") == func_name:
             log.info(
                 "The group parameter has no effect when using %s on "
@@ -746,7 +749,7 @@ def chown(path, user, group=None, pgroup=None, follow_symlinks=True):
         path = _resolve_symlink(path)
 
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {}".format(path))
+        raise CommandExecutionError(f"Path not found: {path}")
 
     salt.utils.win_dacl.set_owner(path, user)
     if pgroup:
@@ -817,7 +820,7 @@ def chgrp(path, group):
 
         salt '*' file.chgrp c:\\temp\\test.txt administrators
     """
-    func_name = "{}.chgrp".format(__virtualname__)
+    func_name = f"{__virtualname__}.chgrp"
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; see "
@@ -863,7 +866,7 @@ def stats(path, hash_type="sha256", follow_symlinks=True):
     # This is to mirror the behavior of file.py. `check_file_meta` expects an
     # empty dictionary when the file does not exist
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {}".format(path))
+        raise CommandExecutionError(f"Path not found: {path}")
 
     if follow_symlinks and sys.getwindowsversion().major >= 6:
         path = _resolve_symlink(path)
@@ -966,13 +969,13 @@ def _get_version_type(file_type, file_subtype):
 
     if ret_type == "Driver":
         if file_subtype in driver_subtypes:
-            ret_type = "{} Driver".format(driver_subtypes[file_subtype])
+            ret_type = f"{driver_subtypes[file_subtype]} Driver"
     if ret_type == "Font":
         if file_subtype in font_subtypes:
-            ret_type = "{} Font".format(font_subtypes[file_subtype])
+            ret_type = f"{font_subtypes[file_subtype]} Font"
     if ret_type == "Virtual Device":
         # The Virtual Device Identifier
-        ret_type = "Virtual Device: {}".format(file_subtype)
+        ret_type = f"Virtual Device: {file_subtype}"
     return ret_type
 
 
@@ -1041,9 +1044,9 @@ def version(path):
     """
     # Input validation
     if not os.path.exists(path):
-        raise CommandExecutionError("File not found: {}".format(path))
+        raise CommandExecutionError(f"File not found: {path}")
     if os.path.isdir(path):
-        raise CommandExecutionError("Not a file: {}".format(path))
+        raise CommandExecutionError(f"Not a file: {path}")
     return _get_version(path)
 
 
@@ -1081,9 +1084,9 @@ def version_details(path):
     """
     # Input validation
     if not os.path.exists(path):
-        raise CommandExecutionError("File not found: {}".format(path))
+        raise CommandExecutionError(f"File not found: {path}")
     if os.path.isdir(path):
-        raise CommandExecutionError("Not a file: {}".format(path))
+        raise CommandExecutionError(f"Not a file: {path}")
 
     ret = {}
     try:
@@ -1159,7 +1162,7 @@ def get_attributes(path):
         salt '*' file.get_attributes c:\\temp\\a.txt
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {}".format(path))
+        raise CommandExecutionError(f"Path not found: {path}")
 
     # set up dictionary for attribute values
     attributes = {}
@@ -1241,7 +1244,7 @@ def set_attributes(
         salt '*' file.set_attributes c:\\temp\\a.txt readonly=True hidden=True
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {}".format(path))
+        raise CommandExecutionError(f"Path not found: {path}")
 
     if normal:
         if archive or hidden or notIndexed or readonly or system or temporary:
@@ -1310,7 +1313,7 @@ def set_mode(path, mode):
 
         salt '*' file.set_mode /etc/passwd 0644
     """
-    func_name = "{}.set_mode".format(__virtualname__)
+    func_name = f"{__virtualname__}.set_mode"
     if __opts__.get("fun", "") == func_name:
         log.info(
             "The function %s should not be used on Windows systems; "
@@ -1343,46 +1346,42 @@ def remove(path, force=False):
     # Symlinks. The shutil.rmtree function will remove the contents of
     # the Symlink source in windows.
 
-    path = os.path.expanduser(path)
+    path = pathlib.Path(os.path.expanduser(path))
 
-    if not os.path.isabs(path):
-        raise SaltInvocationError("File path must be absolute: {}".format(path))
+    if not path.is_absolute():
+        raise SaltInvocationError(f"File path must be absolute: {path}")
 
     # Does the file/folder exists
-    if not os.path.exists(path) and not is_link(path):
-        raise CommandExecutionError("Path not found: {}".format(path))
+    if not path.exists() and not path.is_symlink():
+        raise CommandExecutionError(f"Path not found: {path}")
 
     # Remove ReadOnly Attribute
+    file_attributes = win32api.GetFileAttributes(str(path))
     if force:
         # Get current file attributes
-        file_attributes = win32api.GetFileAttributes(path)
-        win32api.SetFileAttributes(path, win32con.FILE_ATTRIBUTE_NORMAL)
+        win32api.SetFileAttributes(str(path), win32con.FILE_ATTRIBUTE_NORMAL)
 
     try:
-        if os.path.isfile(path):
+        if path.is_file() or path.is_symlink():
             # A file and a symlinked file are removed the same way
-            os.remove(path)
-        elif is_link(path):
-            # If it's a symlink directory, use the rmdir command
-            os.rmdir(path)
+            path.unlink()
         else:
-            for name in os.listdir(path):
-                item = "{}\\{}".format(path, name)
-                # If its a normal directory, recurse to remove it's contents
-                remove(item, force)
+            for child in path.iterdir():
+                # If it's a normal directory, recurse to remove its contents
+                remove(str(child), force)
 
             # rmdir will work now because the directory is empty
-            os.rmdir(path)
+            path.rmdir()
     except OSError as exc:
         if force:
             # Reset attributes to the original if delete fails.
-            win32api.SetFileAttributes(path, file_attributes)
-        raise CommandExecutionError("Could not remove '{}': {}".format(path, exc))
+            win32api.SetFileAttributes(str(path), file_attributes)
+        raise CommandExecutionError(f"Could not remove '{path}': {exc}")
 
     return True
 
 
-def symlink(src, link, force=False, atomic=False):
+def symlink(src, link, force=False, atomic=False, follow_symlinks=True):
     """
     Create a symbolic link to a file
 
@@ -1407,6 +1406,11 @@ def symlink(src, link, force=False, atomic=False):
             Use atomic file operations to create the symlink
             .. versionadded:: 3006.0
 
+        follow_symlinks (bool):
+            If set to ``False``, use ``os.path.lexists()`` for existence checks
+            instead of ``os.path.exists()``.
+            .. versionadded:: 3007.0
+
     Returns:
 
         bool: ``True`` if successful, otherwise raises ``CommandExecutionError``
@@ -1425,7 +1429,12 @@ def symlink(src, link, force=False, atomic=False):
         )
 
     if not os.path.isabs(link):
-        raise SaltInvocationError("Link path must be absolute: {}".format(link))
+        raise SaltInvocationError(f"Link path must be absolute: {link}")
+
+    if follow_symlinks:
+        exists = os.path.exists
+    else:
+        exists = os.path.lexists
 
     if os.path.islink(link):
         try:
@@ -1438,11 +1447,11 @@ def symlink(src, link, force=False, atomic=False):
             pass
 
         if not force and not atomic:
-            msg = "Found existing symlink: {}".format(link)
+            msg = f"Found existing symlink: {link}"
             raise CommandExecutionError(msg)
 
-    if os.path.exists(link) and not force and not atomic:
-        msg = "Existing path is not a symlink: {}".format(link)
+    if exists(link) and not force and not atomic:
+        msg = f"Existing path is not a symlink: {link}"
         raise CommandExecutionError(msg)
 
     # ensure paths are using the right slashes
@@ -1456,7 +1465,7 @@ def symlink(src, link, force=False, atomic=False):
     th = win32security.OpenProcessToken(win32api.GetCurrentProcess(), desired_access)
     salt.platform.win.elevate_token(th)
 
-    if (os.path.islink(link) or os.path.exists(link)) and force and not atomic:
+    if (os.path.islink(link) or exists(link)) and force and not atomic:
         os.unlink(link)
     elif atomic:
         link_dir = os.path.dirname(link)
@@ -1477,14 +1486,14 @@ def symlink(src, link, force=False, atomic=False):
             return True
         except win32file.error:
             os.remove(temp_link)
-            raise CommandExecutionError("Could not create '{}'".format(link))
+            raise CommandExecutionError(f"Could not create '{link}'")
 
     try:
         win32file.CreateSymbolicLink(link, src, int(is_dir))
         return True
     except win32file.error as exc:
         raise CommandExecutionError(
-            "Could not create '{}' - [{}] {}".format(link, exc.winerror, exc.strerror)
+            f"Could not create '{link}' - [{exc.winerror}] {exc.strerror}"
         )
 
 
@@ -1594,7 +1603,7 @@ def mkdir(
     # Make sure the drive is valid
     drive = os.path.splitdrive(path)[0]
     if not os.path.isdir(drive):
-        raise CommandExecutionError("Drive {} is not mapped".format(drive))
+        raise CommandExecutionError(f"Drive {drive} is not mapped")
 
     path = os.path.expanduser(path)
     path = os.path.expandvars(path)
@@ -1711,12 +1720,12 @@ def makedirs_(
 
     if os.path.isdir(dirname):
         # There's nothing for us to do
-        msg = "Directory '{}' already exists".format(dirname)
+        msg = f"Directory '{dirname}' already exists"
         log.debug(msg)
         return msg
 
     if os.path.exists(dirname):
-        msg = "The path '{}' already exists and is not a directory".format(dirname)
+        msg = f"The path '{dirname}' already exists and is not a directory"
         log.debug(msg)
         return msg
 
@@ -1925,7 +1934,7 @@ def check_perms(
         salt '*' file.check_perms C:\\Temp\\ {} Administrators "{'jsnuffy': {'perms': ['read_attributes', 'read_ea'], 'applies_to': 'files_only'}}"
     """
     if not os.path.exists(path):
-        raise CommandExecutionError("Path not found: {}".format(path))
+        raise CommandExecutionError(f"Path not found: {path}")
 
     path = os.path.expanduser(path)
 
