@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Module for Solaris 10's zonecfg
 
@@ -12,21 +11,15 @@ Module for Solaris 10's zonecfg
 .. warning::
     Oracle Solaris 11's zonecfg is not supported by this module!
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import Python libs
 import logging
 import re
 
-# Import Salt libs
 import salt.utils.args
 import salt.utils.data
 import salt.utils.decorators
 import salt.utils.files
 import salt.utils.path
-
-# Import 3rd-party libs
-from salt.ext import six
 from salt.utils.odict import OrderedDict
 
 log = logging.getLogger(__name__)
@@ -117,9 +110,7 @@ def __virtual__():
             return __virtualname__
     return (
         False,
-        "{0} module can only be loaded in a solaris globalzone.".format(
-            __virtualname__
-        ),
+        f"{__virtualname__} module can only be loaded in a solaris globalzone.",
     )
 
 
@@ -137,7 +128,7 @@ def _parse_value(value):
     """Internal helper for parsing configuration values into python values"""
     if isinstance(value, bool):
         return "true" if value else "false"
-    elif isinstance(value, six.string_types):
+    elif isinstance(value, str):
         # parse compacted notation to dict
         listparser = re.compile(r"""((?:[^,"']|"[^"]*"|'[^']*')+)""")
 
@@ -186,7 +177,7 @@ def _sanitize_value(value):
             new_value.append(v)
             new_value.append(",")
         new_value.append(")")
-        return "".join(six.text_type(v) for v in new_value).replace(",)", ")")
+        return "".join(str(v) for v in new_value).replace(",)", ")")
     elif isinstance(value, list):
         new_value = []
         new_value.append("(")
@@ -201,10 +192,10 @@ def _sanitize_value(value):
                 new_value.append(item)
             new_value.append(",")
         new_value.append(")")
-        return "".join(six.text_type(v) for v in new_value).replace(",)", ")")
+        return "".join(str(v) for v in new_value).replace(",)", ")")
     else:
         # note: we can't use shelx or pipes quote here because it makes zonecfg barf
-        return '"{0}"'.format(value) if " " in value else value
+        return f'"{value}"' if " " in value else value
 
 
 def _dump_cfg(cfg_file):
@@ -242,18 +233,21 @@ def create(zone, brand, zonepath, force=False):
     cfg_file = salt.utils.files.mkstemp()
     with salt.utils.files.fpopen(cfg_file, "w+", mode=0o600) as fp_:
         fp_.write("create -b -F\n" if force else "create -b\n")
-        fp_.write("set brand={0}\n".format(_sanitize_value(brand)))
-        fp_.write("set zonepath={0}\n".format(_sanitize_value(zonepath)))
+        fp_.write(f"set brand={_sanitize_value(brand)}\n")
+        fp_.write(f"set zonepath={_sanitize_value(zonepath)}\n")
 
     # create
     if not __salt__["file.directory_exists"](zonepath):
         __salt__["file.makedirs_perms"](
-            zonepath if zonepath[-1] == "/" else "{0}/".format(zonepath), mode="0700"
+            zonepath if zonepath[-1] == "/" else f"{zonepath}/", mode="0700"
         )
 
     _dump_cfg(cfg_file)
     res = __salt__["cmd.run_all"](
-        "zonecfg -z {zone} -f {cfg}".format(zone=zone, cfg=cfg_file,)
+        "zonecfg -z {zone} -f {cfg}".format(
+            zone=zone,
+            cfg=cfg_file,
+        )
     )
     ret["status"] = res["retcode"] == 0
     ret["message"] = res["stdout"] if ret["status"] else res["stderr"]
@@ -292,7 +286,10 @@ def create_from_template(zone, template):
     # create from template
     _dump_cfg(template)
     res = __salt__["cmd.run_all"](
-        "zonecfg -z {zone} create -t {tmpl} -F".format(zone=zone, tmpl=template,)
+        "zonecfg -z {zone} create -t {tmpl} -F".format(
+            zone=zone,
+            tmpl=template,
+        )
     )
     ret["status"] = res["retcode"] == 0
     ret["message"] = res["stdout"] if ret["status"] else res["stderr"]
@@ -320,7 +317,11 @@ def delete(zone):
     ret = {"status": True}
 
     # delete zone
-    res = __salt__["cmd.run_all"]("zonecfg -z {zone} delete -F".format(zone=zone,))
+    res = __salt__["cmd.run_all"](
+        "zonecfg -z {zone} delete -F".format(
+            zone=zone,
+        )
+    )
     ret["status"] = res["retcode"] == 0
     ret["message"] = res["stdout"] if ret["status"] else res["stderr"]
     if ret["message"] == "":
@@ -352,7 +353,8 @@ def export(zone, path=None):
     # export zone
     res = __salt__["cmd.run_all"](
         "zonecfg -z {zone} export{path}".format(
-            zone=zone, path=" -f {0}".format(path) if path else "",
+            zone=zone,
+            path=f" -f {path}" if path else "",
         )
     )
     ret["status"] = res["retcode"] == 0
@@ -385,7 +387,10 @@ def import_(zone, path):
     # create from file
     _dump_cfg(path)
     res = __salt__["cmd.run_all"](
-        "zonecfg -z {zone} -f {path}".format(zone=zone, path=path,)
+        "zonecfg -z {zone} -f {path}".format(
+            zone=zone,
+            path=path,
+        )
     )
     ret["status"] = res["retcode"] == 0
     ret["message"] = res["stdout"] if ret["status"] else res["stderr"]
@@ -417,27 +422,26 @@ def _property(methode, zone, key, value):
     cfg_file = None
     if methode not in ["set", "clear"]:
         ret["status"] = False
-        ret["message"] = "unkown methode {0}!".format(methode)
+        ret["message"] = f"unkown methode {methode}!"
     else:
         cfg_file = salt.utils.files.mkstemp()
         with salt.utils.files.fpopen(cfg_file, "w+", mode=0o600) as fp_:
             if methode == "set":
                 if isinstance(value, dict) or isinstance(value, list):
                     value = _sanitize_value(value)
-                value = (
-                    six.text_type(value).lower()
-                    if isinstance(value, bool)
-                    else six.text_type(value)
-                )
-                fp_.write("{0} {1}={2}\n".format(methode, key, _sanitize_value(value)))
+                value = str(value).lower() if isinstance(value, bool) else str(value)
+                fp_.write(f"{methode} {key}={_sanitize_value(value)}\n")
             elif methode == "clear":
-                fp_.write("{0} {1}\n".format(methode, key))
+                fp_.write(f"{methode} {key}\n")
 
     # update property
     if cfg_file:
         _dump_cfg(cfg_file)
         res = __salt__["cmd.run_all"](
-            "zonecfg -z {zone} -f {path}".format(zone=zone, path=cfg_file,)
+            "zonecfg -z {zone} -f {path}".format(
+                zone=zone,
+                path=cfg_file,
+            )
         )
         ret["status"] = res["retcode"] == 0
         ret["message"] = res["stdout"] if ret["status"] else res["stderr"]
@@ -470,7 +474,12 @@ def set_property(zone, key, value):
 
         salt '*' zonecfg.set_property deathscythe cpu-shares 100
     """
-    return _property("set", zone, key, value,)
+    return _property(
+        "set",
+        zone,
+        key,
+        value,
+    )
 
 
 def clear_property(zone, key):
@@ -488,7 +497,12 @@ def clear_property(zone, key):
 
         salt '*' zonecfg.clear_property deathscythe cpu-shares
     """
-    return _property("clear", zone, key, None,)
+    return _property(
+        "clear",
+        zone,
+        key,
+        None,
+    )
 
 
 def _resource(methode, zone, resource_type, resource_selector, **kwargs):
@@ -516,11 +530,11 @@ def _resource(methode, zone, resource_type, resource_selector, **kwargs):
             kwargs[k] = _sanitize_value(kwargs[k])
     if methode not in ["add", "update"]:
         ret["status"] = False
-        ret["message"] = "unknown methode {0}".format(methode)
+        ret["message"] = f"unknown methode {methode}"
         return ret
     if methode in ["update"] and resource_selector and resource_selector not in kwargs:
         ret["status"] = False
-        ret["message"] = "resource selector {0} not found in parameters".format(
+        ret["message"] = "resource selector {} not found in parameters".format(
             resource_selector
         )
         return ret
@@ -529,43 +543,40 @@ def _resource(methode, zone, resource_type, resource_selector, **kwargs):
     cfg_file = salt.utils.files.mkstemp()
     with salt.utils.files.fpopen(cfg_file, "w+", mode=0o600) as fp_:
         if methode in ["add"]:
-            fp_.write("add {0}\n".format(resource_type))
+            fp_.write(f"add {resource_type}\n")
         elif methode in ["update"]:
             if resource_selector:
                 value = kwargs[resource_selector]
                 if isinstance(value, dict) or isinstance(value, list):
                     value = _sanitize_value(value)
-                value = (
-                    six.text_type(value).lower()
-                    if isinstance(value, bool)
-                    else six.text_type(value)
-                )
+                value = str(value).lower() if isinstance(value, bool) else str(value)
                 fp_.write(
-                    "select {0} {1}={2}\n".format(
+                    "select {} {}={}\n".format(
                         resource_type, resource_selector, _sanitize_value(value)
                     )
                 )
             else:
-                fp_.write("select {0}\n".format(resource_type))
-        for k, v in six.iteritems(kwargs):
+                fp_.write(f"select {resource_type}\n")
+        for k, v in kwargs.items():
             if methode in ["update"] and k == resource_selector:
                 continue
             if isinstance(v, dict) or isinstance(v, list):
                 value = _sanitize_value(value)
-            value = (
-                six.text_type(v).lower() if isinstance(v, bool) else six.text_type(v)
-            )
+            value = str(v).lower() if isinstance(v, bool) else str(v)
             if k in _zonecfg_resource_setters[resource_type]:
-                fp_.write("set {0}={1}\n".format(k, _sanitize_value(value)))
+                fp_.write(f"set {k}={_sanitize_value(value)}\n")
             else:
-                fp_.write("add {0} {1}\n".format(k, _sanitize_value(value)))
+                fp_.write(f"add {k} {_sanitize_value(value)}\n")
         fp_.write("end\n")
 
     # update property
     if cfg_file:
         _dump_cfg(cfg_file)
         res = __salt__["cmd.run_all"](
-            "zonecfg -z {zone} -f {path}".format(zone=zone, path=cfg_file,)
+            "zonecfg -z {zone} -f {path}".format(
+                zone=zone,
+                path=cfg_file,
+            )
         )
         ret["status"] = res["retcode"] == 0
         ret["message"] = res["stdout"] if ret["status"] else res["stderr"]
@@ -655,18 +666,21 @@ def remove_resource(zone, resource_type, resource_key, resource_value):
     with salt.utils.files.fpopen(cfg_file, "w+", mode=0o600) as fp_:
         if resource_key:
             fp_.write(
-                "remove {0} {1}={2}\n".format(
+                "remove {} {}={}\n".format(
                     resource_type, resource_key, _sanitize_value(resource_value)
                 )
             )
         else:
-            fp_.write("remove {0}\n".format(resource_type))
+            fp_.write(f"remove {resource_type}\n")
 
     # update property
     if cfg_file:
         _dump_cfg(cfg_file)
         res = __salt__["cmd.run_all"](
-            "zonecfg -z {zone} -f {path}".format(zone=zone, path=cfg_file,)
+            "zonecfg -z {zone} -f {path}".format(
+                zone=zone,
+                path=cfg_file,
+            )
         )
         ret["status"] = res["retcode"] == 0
         ret["message"] = res["stdout"] if ret["status"] else res["stderr"]
@@ -700,7 +714,11 @@ def info(zone, show_all=False):
     ret = {}
 
     # dump zone
-    res = __salt__["cmd.run_all"]("zonecfg -z {zone} info".format(zone=zone,))
+    res = __salt__["cmd.run_all"](
+        "zonecfg -z {zone} info".format(
+            zone=zone,
+        )
+    )
     if res["retcode"] == 0:
         # parse output
         resname = None
@@ -781,6 +799,3 @@ def info(zone, show_all=False):
             ret[resname].append(resdata)
 
     return ret
-
-
-# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
