@@ -372,7 +372,6 @@ You can also select a custom merging strategy using a ``__`` object in a list:
 +----------------+-------------------------+-------------------------+
 """
 
-
 import functools
 import logging
 import os
@@ -380,8 +379,8 @@ import os
 import salt.utils.yaml
 
 try:
-    from mako.lookup import TemplateLookup  # pylint: disable=no-name-in-module
-    from mako import exceptions  # pylint: disable=no-name-in-module
+    from mako import exceptions
+    from mako.lookup import TemplateLookup
 
     HAS_MAKO = True
 except ImportError:
@@ -417,8 +416,9 @@ def ext_pillar(minion_id, pillar, *args, **kwargs):
         t, matcher = matcher.split(":", 1)
         if t not in traverse:
             raise Exception(
-                'Unknown traverse option "{}", '
-                "should be one of {}".format(t, traverse.keys())
+                'Unknown traverse option "{}", should be one of {}'.format(
+                    t, traverse.keys()
+                )
             )
         cfgs = matchs.get(traverse[t](matcher, None), [])
         if not isinstance(cfgs, list):
@@ -498,9 +498,7 @@ def _cleanup(obj):
 def _merge_dict(stack, obj):
     strategy = obj.pop("__", "merge-last")
     if strategy not in strategies:
-        raise Exception(
-            'Unknown strategy "{}", should be one of {}'.format(strategy, strategies)
-        )
+        raise Exception(f'Unknown strategy "{strategy}", should be one of {strategies}')
     if strategy == "overwrite":
         return _cleanup(obj)
     else:
@@ -537,9 +535,7 @@ def _merge_list(stack, obj):
         strategy = obj[0]["__"]
         del obj[0]
     if strategy not in strategies:
-        raise Exception(
-            'Unknown strategy "{}", should be one of {}'.format(strategy, strategies)
-        )
+        raise Exception(f'Unknown strategy "{strategy}", should be one of {strategies}')
     if strategy == "overwrite":
         return obj
     elif strategy == "remove":
