@@ -1,15 +1,10 @@
-# -*- coding: utf-8 -*-
 """
 Read/Write multiple returners
 
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
-# Import salt libs
 import salt.minion
 
 log = logging.getLogger(__name__)
@@ -46,13 +41,9 @@ def prep_jid(nocache=False, passed_jid=None):
     jid = passed_jid
     for returner_ in __opts__[CONFIG_KEY]:
         if jid is None:
-            jid = _mminion().returners["{0}.prep_jid".format(returner_)](
-                nocache=nocache
-            )
+            jid = _mminion().returners[f"{returner_}.prep_jid"](nocache=nocache)
         else:
-            r_jid = _mminion().returners["{0}.prep_jid".format(returner_)](
-                nocache=nocache
-            )
+            r_jid = _mminion().returners[f"{returner_}.prep_jid"](nocache=nocache)
             if r_jid != jid:
                 log.debug("Uhh.... crud the jids do not match")
     return jid
@@ -63,7 +54,7 @@ def returner(load):
     Write return to all returners in multi_returner
     """
     for returner_ in __opts__[CONFIG_KEY]:
-        _mminion().returners["{0}.returner".format(returner_)](load)
+        _mminion().returners[f"{returner_}.returner"](load)
 
 
 def save_load(jid, clear_load, minions=None):
@@ -71,7 +62,7 @@ def save_load(jid, clear_load, minions=None):
     Write load to all returners in multi_returner
     """
     for returner_ in __opts__[CONFIG_KEY]:
-        _mminion().returners["{0}.save_load".format(returner_)](jid, clear_load)
+        _mminion().returners[f"{returner_}.save_load"](jid, clear_load)
 
 
 def save_minions(jid, minions, syndic_id=None):  # pylint: disable=unused-argument
@@ -86,7 +77,7 @@ def get_load(jid):
     """
     ret = {}
     for returner_ in __opts__[CONFIG_KEY]:
-        ret.update(_mminion().returners["{0}.get_load".format(returner_)](jid))
+        ret.update(_mminion().returners[f"{returner_}.get_load"](jid))
 
     return ret
 
@@ -97,7 +88,7 @@ def get_jid(jid):
     """
     ret = {}
     for returner_ in __opts__[CONFIG_KEY]:
-        ret.update(_mminion().returners["{0}.get_jid".format(returner_)](jid))
+        ret.update(_mminion().returners[f"{returner_}.get_jid"](jid))
 
     return ret
 
@@ -108,7 +99,7 @@ def get_jids():
     """
     ret = {}
     for returner_ in __opts__[CONFIG_KEY]:
-        ret.update(_mminion().returners["{0}.get_jids".format(returner_)]())
+        ret.update(_mminion().returners[f"{returner_}.get_jids"]())
 
     return ret
 
@@ -118,6 +109,6 @@ def clean_old_jobs():
     Clean out the old jobs from all returners (if you have it)
     """
     for returner_ in __opts__[CONFIG_KEY]:
-        fstr = "{0}.clean_old_jobs".format(returner_)
+        fstr = f"{returner_}.clean_old_jobs"
         if fstr in _mminion().returners:
             _mminion().returners[fstr]()
