@@ -3,7 +3,6 @@ General management functions for salt, tools like seeing what hosts are up
 and what hosts are down
 """
 
-
 import logging
 import operator
 import os
@@ -134,7 +133,7 @@ def key_regen():
             path = os.path.join(root, fn_)
             try:
                 os.remove(path)
-            except os.error:
+            except OSError:
                 pass
     msg = (
         "The minion and master keys have been deleted.  Restart the Salt\n"
@@ -538,12 +537,12 @@ def safe_accept(target, tgt_type="glob"):
                 del ret[minion]
                 continue
             elif minion not in pending:
-                failures[minion] = "Minion key {} not found by salt-key".format(minion)
+                failures[minion] = f"Minion key {minion} not found by salt-key"
             elif pending[minion] != finger:
-                failures[
-                    minion
-                ] = "Minion key {} does not match the key in salt-key: {}".format(
-                    finger, pending[minion]
+                failures[minion] = (
+                    "Minion key {} does not match the key in salt-key: {}".format(
+                        finger, pending[minion]
+                    )
                 )
             else:
                 subprocess.call(["salt-key", "-qya", minion])
@@ -559,9 +558,7 @@ def safe_accept(target, tgt_type="glob"):
             print(message)
             print("")
 
-    __jid_event__.fire_event(
-        {"message": "Accepted {:d} keys".format(len(ret))}, "progress"
-    )
+    __jid_event__.fire_event({"message": f"Accepted {len(ret):d} keys"}, "progress")
     return ret, failures
 
 
@@ -730,8 +727,8 @@ def bootstrap(
             client_opts["argv"] = [
                 "http.query",
                 script,
-                "backend={}".format(http_backend),
-                "text_out={}".format(deploy_command),
+                f"backend={http_backend}",
+                f"text_out={deploy_command}",
             ]
             salt.client.ssh.SSH(client_opts).run()
             client_opts["argv"] = [
@@ -846,7 +843,7 @@ objShell.Exec("{1}{2}")"""
     vb_saltexec = "saltinstall.exe"
     vb_saltexec_args = " /S /minion-name=%COMPUTERNAME%"
     if master:
-        vb_saltexec_args += " /master={}".format(master)
+        vb_saltexec_args += f" /master={master}"
 
     # One further thing we need to do; the Windows Salt minion is pretty
     # self-contained, except for the Microsoft Visual C++ 2008 runtime.
