@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage Elasticache
 ==================
@@ -76,9 +75,6 @@ passed in as a dict, or as a string to pull from pillars or minion config:
             key: askdjghsdfjkghWupUjasdflkdfklgjsdfjajkghs
 """
 
-# Import Python Libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
 log = logging.getLogger(__name__)
@@ -230,7 +226,7 @@ def present(
         return ret
     elif not config:
         if __opts__["test"]:
-            msg = "Cache cluster {0} is set to be created.".format(name)
+            msg = f"Cache cluster {name} is set to be created."
             ret["comment"] = msg
             ret["result"] = None
             return ret
@@ -264,11 +260,11 @@ def present(
             ret["changes"]["new"] = config
         else:
             ret["result"] = False
-            ret["comment"] = "Failed to create {0} cache cluster.".format(name)
+            ret["comment"] = f"Failed to create {name} cache cluster."
             return ret
     # TODO: support modification of existing elasticache clusters
     else:
-        ret["comment"] = "Cache cluster {0} is present.".format(name)
+        ret["comment"] = f"Cache cluster {name} is present."
     return ret
 
 
@@ -323,7 +319,7 @@ def subnet_group_present(
     )
     if not exists:
         if __opts__["test"]:
-            ret["comment"] = "Subnet group {0} is set to be created.".format(name)
+            ret["comment"] = f"Subnet group {name} is set to be created."
             ret["result"] = None
             return ret
         created = __salt__["boto_elasticache.create_subnet_group"](
@@ -339,11 +335,11 @@ def subnet_group_present(
         )
         if not created:
             ret["result"] = False
-            ret["comment"] = "Failed to create {0} subnet group.".format(name)
+            ret["comment"] = f"Failed to create {name} subnet group."
             return ret
         ret["changes"]["old"] = None
         ret["changes"]["new"] = name
-        ret["comment"] = "Subnet group {0} created.".format(name)
+        ret["comment"] = f"Subnet group {name} created."
         return ret
     ret["comment"] = "Subnet group present."
     return ret
@@ -383,7 +379,7 @@ def absent(name, wait=True, region=None, key=None, keyid=None, profile=None):
 
     if is_present:
         if __opts__["test"]:
-            ret["comment"] = "Cache cluster {0} is set to be removed.".format(name)
+            ret["comment"] = f"Cache cluster {name} is set to be removed."
             ret["result"] = None
             return ret
         deleted = __salt__["boto_elasticache.delete"](
@@ -394,9 +390,9 @@ def absent(name, wait=True, region=None, key=None, keyid=None, profile=None):
             ret["changes"]["new"] = None
         else:
             ret["result"] = False
-            ret["comment"] = "Failed to delete {0} cache cluster.".format(name)
+            ret["comment"] = f"Failed to delete {name} cache cluster."
     else:
-        ret["comment"] = "{0} does not exist in {1}.".format(name, region)
+        ret["comment"] = f"{name} does not exist in {region}."
     return ret
 
 
@@ -448,7 +444,7 @@ def creategroup(
     )
     if not is_present:
         if __opts__["test"]:
-            ret["comment"] = "Replication {0} is set to be created.".format(name)
+            ret["comment"] = f"Replication {name} is set to be created."
             ret["result"] = None
         created = __salt__["boto_elasticache.create_replication_group"](
             name,
@@ -469,9 +465,9 @@ def creategroup(
             ret["result"] = True
         else:
             ret["result"] = False
-            ret["comment"] = "Failed to create {0} replication group.".format(name)
+            ret["comment"] = f"Failed to create {name} replication group."
     else:
-        ret["comment"] = "{0} replication group exists .".format(name)
+        ret["comment"] = f"{name} replication group exists ."
         ret["result"] = True
     return ret
 
@@ -486,11 +482,11 @@ def subnet_group_absent(
     )
     if not exists:
         ret["result"] = True
-        ret["comment"] = "{0} ElastiCache subnet group does not exist.".format(name)
+        ret["comment"] = f"{name} ElastiCache subnet group does not exist."
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "ElastiCache subnet group {0} is set to be removed.".format(
+        ret["comment"] = "ElastiCache subnet group {} is set to be removed.".format(
             name
         )
         ret["result"] = None
@@ -500,11 +496,11 @@ def subnet_group_absent(
     )
     if not deleted:
         ret["result"] = False
-        ret["comment"] = "Failed to delete {0} ElastiCache subnet group.".format(name)
+        ret["comment"] = f"Failed to delete {name} ElastiCache subnet group."
         return ret
     ret["changes"]["old"] = name
     ret["changes"]["new"] = None
-    ret["comment"] = "ElastiCache subnet group {0} deleted.".format(name)
+    ret["comment"] = f"ElastiCache subnet group {name} deleted."
     return ret
 
 
@@ -518,16 +514,12 @@ def replication_group_absent(
     )
     if not exists:
         ret["result"] = True
-        ret["comment"] = "{0} ElastiCache replication group does not exist.".format(
-            name
-        )
+        ret["comment"] = f"{name} ElastiCache replication group does not exist."
         log.info(ret["comment"])
         return ret
 
     if __opts__["test"]:
-        ret[
-            "comment"
-        ] = "ElastiCache replication group {0} is set to be removed.".format(name)
+        ret["comment"] = f"ElastiCache replication group {name} is set to be removed."
         ret["result"] = True
         return ret
     deleted = __salt__["boto_elasticache.delete_replication_group"](
@@ -536,12 +528,12 @@ def replication_group_absent(
     if not deleted:
         ret["result"] = False
         log.error(ret["comment"])
-        ret["comment"] = "Failed to delete {0} ElastiCache replication group.".format(
+        ret["comment"] = "Failed to delete {} ElastiCache replication group.".format(
             name
         )
         return ret
     ret["changes"]["old"] = name
     ret["changes"]["new"] = None
-    ret["comment"] = "ElastiCache replication group {0} deleted.".format(name)
+    ret["comment"] = f"ElastiCache replication group {name} deleted."
     log.info(ret["comment"])
     return ret
