@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage RDSs
 ===========
@@ -69,18 +68,12 @@ config:
 
 """
 
-# Import Python Libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import os
 
 import salt.utils.data
 from salt.exceptions import SaltInvocationError
 
-# Import Salt Libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 
@@ -312,7 +305,7 @@ def present(
 
     if not r.get("exists"):
         if __opts__["test"]:
-            ret["comment"] = "RDS instance {0} would be created.".format(name)
+            ret["comment"] = f"RDS instance {name} would be created."
             ret["result"] = None
             return ret
 
@@ -364,7 +357,7 @@ def present(
 
         if not r.get("created"):
             ret["result"] = False
-            ret["comment"] = "Failed to create RDS instance {0}.".format(
+            ret["comment"] = "Failed to create RDS instance {}.".format(
                 r["error"]["message"]
             )
             return ret
@@ -380,9 +373,9 @@ def present(
                 profile=profile,
             )
         }
-        ret["comment"] = "RDS instance {0} created.".format(name)
+        ret["comment"] = f"RDS instance {name} created."
     else:
-        ret["comment"] = "RDS instance {0} exists.".format(name)
+        ret["comment"] = f"RDS instance {name} exists."
     return ret
 
 
@@ -419,7 +412,7 @@ def replica_present(
     )
     if not replica_exists.get("exists"):
         if __opts__["test"]:
-            ret["comment"] = "RDS read replica {0} is set to be created ".format(name)
+            ret["comment"] = f"RDS read replica {name} is set to be created "
             ret["result"] = None
             return ret
         created = __salt__["boto_rds.create_read_replica"](
@@ -439,7 +432,7 @@ def replica_present(
             profile,
         )
         if created:
-            ret["comment"] = "RDS replica {0} created.".format(name)
+            ret["comment"] = f"RDS replica {name} created."
             ret["changes"]["old"] = {"instance": None}
             ret["changes"]["new"] = {
                 "instance": __salt__["boto_rds.describe_db_instances"](
@@ -453,7 +446,7 @@ def replica_present(
             }
         else:
             ret["result"] = False
-            ret["comment"] = "Failed to create RDS replica {0}.".format(name)
+            ret["comment"] = f"Failed to create RDS replica {name}."
     else:
         jmespath = "DBInstances[0].DBParameterGroups[0].DBParameterGroupName"
         pmg_name = __salt__["boto_rds.describe_db_instances"](
@@ -477,13 +470,12 @@ def replica_present(
             if not modified:
                 ret["result"] = False
                 ret["comment"] = (
-                    "Failed to update parameter group of {0} RDS "
-                    "instance.".format(name)
+                    f"Failed to update parameter group of {name} RDS instance."
                 )
             ret["changes"]["old"] = pmg_name
             ret["changes"]["new"] = db_parameter_group_name
         ret["result"] = True
-        ret["comment"] = "RDS replica {0} exists.".format(name)
+        ret["comment"] = f"RDS replica {name} exists."
     return ret
 
 
@@ -533,7 +525,7 @@ def subnet_group_present(
     """
     if not salt.utils.data.exactly_one((subnet_ids, subnet_names)):
         raise SaltInvocationError(
-            "One (but not both) of subnet_ids or " "subnet_names must be provided."
+            "One (but not both) of subnet_ids or subnet_names must be provided."
         )
 
     ret = {"name": name, "result": True, "comment": "", "changes": {}}
@@ -548,13 +540,13 @@ def subnet_group_present(
             )
 
             if "error" in r:
-                ret["comment"] = "Error looking up subnet ids: {0}".format(
+                ret["comment"] = "Error looking up subnet ids: {}".format(
                     r["error"]["message"]
                 )
                 ret["result"] = False
                 return ret
             if r["id"] is None:
-                ret["comment"] = "Subnet {0} does not exist.".format(i)
+                ret["comment"] = f"Subnet {i} does not exist."
                 ret["result"] = False
                 return ret
             subnet_ids.append(r["id"])
@@ -564,7 +556,7 @@ def subnet_group_present(
     )
     if not exists.get("exists"):
         if __opts__["test"]:
-            ret["comment"] = "Subnet group {0} is set to be created.".format(name)
+            ret["comment"] = f"Subnet group {name} is set to be created."
             ret["result"] = None
             return ret
         created = __salt__["boto_rds.create_subnet_group"](
@@ -580,14 +572,14 @@ def subnet_group_present(
 
         if not created:
             ret["result"] = False
-            ret["comment"] = "Failed to create {0} subnet group.".format(name)
+            ret["comment"] = f"Failed to create {name} subnet group."
             return ret
         ret["changes"]["old"] = None
         ret["changes"]["new"] = name
-        ret["comment"] = "Subnet {0} created.".format(name)
+        ret["comment"] = f"Subnet {name} created."
         return ret
     else:
-        ret["comment"] = "Subnet {0} present.".format(name)
+        ret["comment"] = f"Subnet {name} present."
 
         return ret
 
@@ -649,11 +641,11 @@ def absent(
     )
     if not current:
         ret["result"] = True
-        ret["comment"] = "{0} RDS already absent.".format(name)
+        ret["comment"] = f"{name} RDS already absent."
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "RDS {0} would be removed.".format(name)
+        ret["comment"] = f"RDS {name} would be removed."
         ret["result"] = None
         return ret
     deleted = __salt__["boto_rds.delete"](
@@ -670,11 +662,11 @@ def absent(
     )
     if not deleted:
         ret["result"] = False
-        ret["comment"] = "Failed to delete {0} RDS.".format(name)
+        ret["comment"] = f"Failed to delete {name} RDS."
         return ret
     ret["changes"]["old"] = {"instance": current[0]}
     ret["changes"]["new"] = {"instance": None}
-    ret["comment"] = "RDS {0} deleted.".format(name)
+    ret["comment"] = f"RDS {name} deleted."
     return ret
 
 
@@ -688,11 +680,11 @@ def subnet_group_absent(
     )
     if not exists:
         ret["result"] = True
-        ret["comment"] = "{0} RDS subnet group does not exist.".format(name)
+        ret["comment"] = f"{name} RDS subnet group does not exist."
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "RDS subnet group {0} is set to be removed.".format(name)
+        ret["comment"] = f"RDS subnet group {name} is set to be removed."
         ret["result"] = None
         return ret
     deleted = __salt__["boto_rds.delete_subnet_group"](
@@ -700,11 +692,11 @@ def subnet_group_absent(
     )
     if not deleted:
         ret["result"] = False
-        ret["comment"] = "Failed to delete {0} RDS subnet group.".format(name)
+        ret["comment"] = f"Failed to delete {name} RDS subnet group."
         return ret
     ret["changes"]["old"] = name
     ret["changes"]["new"] = None
-    ret["comment"] = "RDS subnet group {0} deleted.".format(name)
+    ret["comment"] = f"RDS subnet group {name} deleted."
     return ret
 
 
@@ -769,7 +761,7 @@ def parameter_present(
     )
     if not res.get("exists"):
         if __opts__["test"]:
-            ret["comment"] = "Parameter group {0} is set to be created.".format(name)
+            ret["comment"] = f"Parameter group {name} is set to be created."
             ret["result"] = None
             return ret
         created = __salt__["boto_rds.create_parameter_group"](
@@ -784,12 +776,12 @@ def parameter_present(
         )
         if not created:
             ret["result"] = False
-            ret["comment"] = "Failed to create {0} parameter group.".format(name)
+            ret["comment"] = f"Failed to create {name} parameter group."
             return ret
         ret["changes"]["New Parameter Group"] = name
-        ret["comment"] = "Parameter group {0} created.".format(name)
+        ret["comment"] = f"Parameter group {name} created."
     else:
-        ret["comment"] = "Parameter group {0} present.".format(name)
+        ret["comment"] = f"Parameter group {name} present."
     if parameters is not None:
         params = {}
         changed = {}
@@ -798,7 +790,7 @@ def parameter_present(
                 if type(value) is bool:
                     params[k] = "on" if value else "off"
                 else:
-                    params[k] = six.text_type(value)
+                    params[k] = str(value)
         log.debug("Parameters from user are : %s.", params)
         options = __salt__["boto_rds.describe_parameters"](
             name=name, region=region, key=key, keyid=keyid, profile=profile
@@ -806,13 +798,13 @@ def parameter_present(
         if not options.get("result"):
             ret["result"] = False
             ret["comment"] = os.linesep.join(
-                [ret["comment"], "Faled to get parameters for group  {0}.".format(name)]
+                [ret["comment"], f"Faled to get parameters for group  {name}."]
             )
             return ret
         for parameter in options["parameters"].values():
             if parameter["ParameterName"] in params and params.get(
                 parameter["ParameterName"]
-            ) != six.text_type(parameter["ParameterValue"]):
+            ) != str(parameter["ParameterValue"]):
                 log.debug(
                     "Values that are being compared for %s are %s:%s.",
                     parameter["ParameterName"],
@@ -827,7 +819,7 @@ def parameter_present(
                 ret["comment"] = os.linesep.join(
                     [
                         ret["comment"],
-                        "Parameters {0} for group {1} are set to be changed.".format(
+                        "Parameters {} for group {} are set to be changed.".format(
                             changed, name
                         ),
                     ]
@@ -849,7 +841,7 @@ def parameter_present(
                 ret["comment"] = os.linesep.join(
                     [
                         ret["comment"],
-                        "Failed to change parameters {0} for group {1}:".format(
+                        "Failed to change parameters {} for group {}:".format(
                             changed, name
                         ),
                         update["error"]["message"],
@@ -860,14 +852,14 @@ def parameter_present(
             ret["comment"] = os.linesep.join(
                 [
                     ret["comment"],
-                    "Parameters {0} for group {1} are changed.".format(changed, name),
+                    f"Parameters {changed} for group {name} are changed.",
                 ]
             )
         else:
             ret["comment"] = os.linesep.join(
                 [
                     ret["comment"],
-                    "Parameters {0} for group {1} are present.".format(params, name),
+                    f"Parameters {params} for group {name} are present.",
                 ]
             )
     return ret
