@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Management of Dell DRAC
 
@@ -36,7 +35,6 @@ Ensure DRAC network is in a consistent state
         - gateway: 10.225.108.1
 
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import salt.exceptions
 import salt.utils.path
@@ -70,18 +68,18 @@ def present(name, password, permission):
 
     if __opts__["test"]:
         if name in users:
-            ret["comment"] = "`{0}` already exists".format(name)
+            ret["comment"] = f"`{name}` already exists"
         else:
-            ret["comment"] = "`{0}` will be created".format(name)
+            ret["comment"] = f"`{name}` will be created"
             ret["changes"] = {name: "will be created"}
 
         return ret
 
     if name in users:
-        ret["comment"] = "`{0}` already exists".format(name)
+        ret["comment"] = f"`{name}` already exists"
     else:
         if __salt__["drac.create_user"](name, password, permission, users):
-            ret["comment"] = "`{0}` user created".format(name)
+            ret["comment"] = f"`{name}` user created"
             ret["changes"] = {name: "new user created"}
         else:
             ret["comment"] = "Unable to create user"
@@ -103,22 +101,22 @@ def absent(name):
 
     if __opts__["test"]:
         if name in users:
-            ret["comment"] = "`{0}` is set to be deleted".format(name)
+            ret["comment"] = f"`{name}` is set to be deleted"
             ret["changes"] = {name: "will be deleted"}
         else:
-            ret["comment"] = "`{0}` does not exist".format(name)
+            ret["comment"] = f"`{name}` does not exist"
 
         return ret
 
     if name in users:
         if __salt__["drac.delete_user"](name, users[name]["index"]):
-            ret["comment"] = "`{0}` deleted".format(name)
+            ret["comment"] = f"`{name}` deleted"
             ret["changes"] = {name: "deleted"}
         else:
             ret["comment"] = "Unable to delete user"
             ret["result"] = False
     else:
-        ret["comment"] = "`{0}` does not exist".format(name)
+        ret["comment"] = f"`{name}` does not exist"
 
     return ret
 
