@@ -1,19 +1,13 @@
-# -*- coding: utf-8 -*-
 """
 State module to manage Elasticsearch indices
 
 .. versionadded:: 2015.8.0
-.. deprecated:: 2017.7.0 Use elasticsearch state instead
+.. deprecated:: 2017.7.0
+   Use elasticsearch state instead
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
-# Import Salt libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 
@@ -31,23 +25,23 @@ def absent(name):
         index = __salt__["elasticsearch.index_get"](index=name)
         if index and name in index:
             if __opts__["test"]:
-                ret["comment"] = "Index {0} will be removed".format(name)
+                ret["comment"] = f"Index {name} will be removed"
                 ret["changes"]["old"] = index[name]
                 ret["result"] = None
             else:
                 ret["result"] = __salt__["elasticsearch.index_delete"](index=name)
                 if ret["result"]:
-                    ret["comment"] = "Successfully removed index {0}".format(name)
+                    ret["comment"] = f"Successfully removed index {name}"
                     ret["changes"]["old"] = index[name]
                 else:
-                    ret[
-                        "comment"
-                    ] = "Failed to remove index {0} for unknown reasons".format(name)
+                    ret["comment"] = (
+                        f"Failed to remove index {name} for unknown reasons"
+                    )
         else:
-            ret["comment"] = "Index {0} is already absent".format(name)
+            ret["comment"] = f"Index {name} is already absent"
     except Exception as err:  # pylint: disable=broad-except
         ret["result"] = False
-        ret["comment"] = six.text_type(err)
+        ret["comment"] = str(err)
 
     return ret
 
@@ -89,7 +83,7 @@ def present(name, definition=None):
         index_exists = __salt__["elasticsearch.index_exists"](index=name)
         if not index_exists:
             if __opts__["test"]:
-                ret["comment"] = "Index {0} does not exist and will be created".format(
+                ret["comment"] = "Index {} does not exist and will be created".format(
                     name
                 )
                 ret["changes"] = {"new": definition}
@@ -99,17 +93,17 @@ def present(name, definition=None):
                     index=name, body=definition
                 )
                 if output:
-                    ret["comment"] = "Successfully created index {0}".format(name)
+                    ret["comment"] = f"Successfully created index {name}"
                     ret["changes"] = {
                         "new": __salt__["elasticsearch.index_get"](index=name)[name]
                     }
                 else:
                     ret["result"] = False
-                    ret["comment"] = "Cannot create index {0}, {1}".format(name, output)
+                    ret["comment"] = f"Cannot create index {name}, {output}"
         else:
-            ret["comment"] = "Index {0} is already present".format(name)
+            ret["comment"] = f"Index {name} is already present"
     except Exception as err:  # pylint: disable=broad-except
         ret["result"] = False
-        ret["comment"] = six.text_type(err)
+        ret["comment"] = str(err)
 
     return ret
