@@ -82,7 +82,7 @@ def _do_element_present(name, elem_type, data, server=None):
     """
     ret = {"changes": {}, "update": False, "create": False, "error": None}
     try:
-        elements = __salt__["glassfish.enum_{}".format(elem_type)]()
+        elements = __salt__[f"glassfish.enum_{elem_type}"]()
     except requests.ConnectionError as error:
         if __opts__["test"]:
             ret["changes"] = {"Name": name, "Params": data}
@@ -97,23 +97,19 @@ def _do_element_present(name, elem_type, data, server=None):
         ret["create"] = True
         if not __opts__["test"]:
             try:
-                __salt__["glassfish.create_{}".format(elem_type)](
-                    name, server=server, **data
-                )
+                __salt__[f"glassfish.create_{elem_type}"](name, server=server, **data)
             except CommandExecutionError as error:
                 ret["error"] = error
                 return ret
     elif elements and any(data):
-        current_data = __salt__["glassfish.get_{}".format(elem_type)](
-            name, server=server
-        )
+        current_data = __salt__[f"glassfish.get_{elem_type}"](name, server=server)
         data_diff = _is_updated(current_data, data)
         if data_diff:
             ret["update"] = True
             ret["changes"] = data_diff
             if not __opts__["test"]:
                 try:
-                    __salt__["glassfish.update_{}".format(elem_type)](
+                    __salt__[f"glassfish.update_{elem_type}"](
                         name, server=server, **data
                     )
                 except CommandExecutionError as error:
@@ -127,7 +123,7 @@ def _do_element_absent(name, elem_type, data, server=None):
     """
     ret = {"delete": False, "error": None}
     try:
-        elements = __salt__["glassfish.enum_{}".format(elem_type)]()
+        elements = __salt__[f"glassfish.enum_{elem_type}"]()
     except requests.ConnectionError as error:
         if __opts__["test"]:
             ret["create"] = True
@@ -140,9 +136,7 @@ def _do_element_absent(name, elem_type, data, server=None):
         ret["delete"] = True
         if not __opts__["test"]:
             try:
-                __salt__["glassfish.delete_{}".format(elem_type)](
-                    name, server=server, **data
-                )
+                __salt__[f"glassfish.delete_{elem_type}"](name, server=server, **data)
             except CommandExecutionError as error:
                 ret["error"] = error
     return ret
@@ -208,7 +202,7 @@ def connection_factory_present(
     # Manage parameters
     pool_data = {}
     res_data = {}
-    pool_name = "{}-Connection-Pool".format(name)
+    pool_name = f"{name}-Connection-Pool"
     if restype == "topic_connection_factory":
         pool_data["connectionDefinitionName"] = "javax.jms.TopicConnectionFactory"
     elif restype == "queue_connection_factory":
@@ -285,7 +279,7 @@ def connection_factory_absent(name, both=True, server=None):
         Delete both the pool and the resource, defaults to ``true``
     """
     ret = {"name": name, "result": None, "comment": None, "changes": {}}
-    pool_name = "{}-Connection-Pool".format(name)
+    pool_name = f"{name}-Connection-Pool"
     pool_ret = _do_element_absent(
         pool_name, "connector_c_pool", {"cascade": both}, server
     )
@@ -466,7 +460,7 @@ def jdbc_datasource_present(
     ret = {"name": name, "result": None, "comment": None, "changes": {}}
 
     # Manage parameters
-    res_name = "jdbc/{}".format(name)
+    res_name = f"jdbc/{name}"
     pool_data = {}
     pool_data_properties = {}
     res_data = {}
@@ -484,7 +478,9 @@ def jdbc_datasource_present(
         "driver": "com.mysql.jdbc.Driver",
         "datasource": "com.mysql.jdbc.jdbc2.optional.MysqlDataSource",
         "xa_datasource": "com.mysql.jdbc.jdbc2.optional.MysqlXADataSource",
-        "connection_pool_datasource": "com.mysql.jdbc.jdbc2.optional.MysqlConnectionPoolDataSource",
+        "connection_pool_datasource": (
+            "com.mysql.jdbc.jdbc2.optional.MysqlConnectionPoolDataSource"
+        ),
     }
     datasources["postgresql"] = {
         "driver": "org.postgresql.Driver",
@@ -496,7 +492,9 @@ def jdbc_datasource_present(
         "driver": "com.microsoft.sqlserver.jdbc.SQLServerDriver",
         "datasource": "com.microsoft.sqlserver.jdbc.SQLServerDataSource",
         "xa_datasource": "com.microsoft.sqlserver.jdbc.SQLServerXADataSource",
-        "connection_pool_datasource": "com.microsoft.sqlserver.jdbc.SQLServerConnectionPoolDataSource",
+        "connection_pool_datasource": (
+            "com.microsoft.sqlserver.jdbc.SQLServerConnectionPoolDataSource"
+        ),
     }
 
     if restype == "driver":
