@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Kapacitor state module.
 
@@ -17,9 +16,6 @@ Kapacitor state module.
 .. versionadded:: 2016.11.0
 """
 
-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import difflib
 
 import salt.utils.files
@@ -79,7 +75,7 @@ def task_present(
     if not dbrps:
         dbrps = []
     if database and retention_policy:
-        dbrp = "{0}.{1}".format(database, retention_policy)
+        dbrp = f"{database}.{retention_policy}"
         dbrps.append(dbrp)
     task_dbrps = [
         {"db": dbrp[0], "rp": dbrp[1]} for dbrp in (dbrp.split(".") for dbrp in dbrps)
@@ -126,7 +122,10 @@ def task_present(
 
         if old_script != new_script:
             ret["changes"]["TICKscript diff"] = "\n".join(
-                difflib.unified_diff(old_script.splitlines(), new_script.splitlines(),)
+                difflib.unified_diff(
+                    old_script.splitlines(),
+                    new_script.splitlines(),
+                )
             )
             comments.append("Task script updated")
 
