@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Linux File Access Control Lists
 
@@ -15,6 +14,17 @@ Ensure a Linux ACL is present
          - acl_name: damian
          - perms: rwx
 
+Ensure a Linux ACL is present as a default for all new objects
+
+.. code-block:: yaml
+
+     root:
+       acl.present:
+         - name: /root
+         - acl_type: "default:user"
+         - acl_name: damian
+         - perms: rwx
+
 Ensure a Linux ACL does not exist
 
 .. code-block:: yaml
@@ -51,10 +61,25 @@ Ensure a Linux ACL list does not exist
            - damian
            - homer
          - perms: rwx
-"""
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
+.. warning::
+
+    The effective permissions of Linux file access control lists (ACLs) are
+    governed by the "effective rights mask" (the `mask` line in the output of
+    the `getfacl` command) combined with the `perms` set by this module: any
+    permission bits (for example, r=read) present in an ACL but not in the mask
+    are ignored.  The mask is automatically recomputed when setting an ACL, so
+    normally this isn't important.  However, if the file permissions are
+    changed (with `chmod` or `file.managed`, for example), the mask will
+    generally be set based on just the group bits of the file permissions.
+
+    As a result, when using `file.managed` or similar to control file
+    permissions as well as this module, you should set your group permissions
+    to be at least as broad as any permissions in your ACL. Otherwise, the two
+    state declarations will each register changes each run, and if the `file`
+    declaration runs later, your ACL will be ineffective.
+
+"""
 
 import logging
 import os
@@ -62,9 +87,6 @@ import os
 import salt.utils.path
 from salt.exceptions import CommandExecutionError
 
-# Import salt libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 __virtualname__ = "acl"
@@ -79,7 +101,8 @@ def __virtual__():
 
     return (
         False,
-        "The linux_acl state cannot be loaded: the getfacl or setfacl binary is not in the path.",
+        "The linux_acl state cannot be loaded: the getfacl or setfacl binary is not in"
+        " the path.",
     )
 
 
@@ -111,7 +134,7 @@ def present(name, acl_type, acl_name="", perms="", recurse=False, force=False):
     _octal_lookup = {0: "-", 1: "r", 2: "w", 4: "x"}
 
     if not os.path.exists(name):
-        ret["comment"] = "{0} does not exist".format(name)
+        ret["comment"] = f"{name} does not exist"
         ret["result"] = False
         return ret
 
@@ -144,13 +167,13 @@ def present(name, acl_type, acl_name="", perms="", recurse=False, force=False):
             user = [
                 i
                 for i in _current_perms[_acl_type]
-                if next(six.iterkeys(i)) == _search_name
+                if next(iter(i.keys())) == _search_name
             ].pop()
         except (AttributeError, IndexError, StopIteration, KeyError):
             user = None
 
         if user:
-            octal_sum = sum([_octal.get(i, i) for i in perms])
+            octal_sum = sum(_octal.get(i, i) for i in perms)
             need_refresh = False
             # If recursive check all paths retrieved via acl.getfacl
             if recurse:
@@ -174,7 +197,7 @@ def present(name, acl_type, acl_name="", perms="", recurse=False, force=False):
                         break
 
             # Check the permissions from the already located file
-            elif user[_search_name]["octal"] == sum([_octal.get(i, i) for i in perms]):
+            elif user[_search_name]["octal"] == sum(_octal.get(i, i) for i in perms):
                 need_refresh = False
             # If they don't match then refresh
             else:
@@ -201,8 +224,10 @@ def present(name, acl_type, acl_name="", perms="", recurse=False, force=False):
                 if __opts__["test"]:
                     ret.update(
                         {
-                            "comment": "Updated permissions will be applied for "
-                            "{0}: {1} -> {2}".format(acl_name, new_perms, perms),
+                            "comment": (
+                                "Updated permissions will be applied for "
+                                "{}: {} -> {}".format(acl_name, new_perms, perms)
+                            ),
                             "result": None,
                             "changes": changes,
                         }
@@ -224,8 +249,7 @@ def present(name, acl_type, acl_name="", perms="", recurse=False, force=False):
                     )
                     ret.update(
                         {
-                            "comment": "Updated permissions for "
-                            "{0}".format(acl_name),
+                            "comment": f"Updated permissions for {acl_name}",
                             "result": True,
                             "changes": changes,
                         }
@@ -233,8 +257,9 @@ def present(name, acl_type, acl_name="", perms="", recurse=False, force=False):
                 except CommandExecutionError as exc:
                     ret.update(
                         {
-                            "comment": "Error updating permissions for "
-                            "{0}: {1}".format(acl_name, exc.strerror),
+                            "comment": "Error updating permissions for {}: {}".format(
+                                acl_name, exc.strerror
+                            ),
                             "result": False,
                         }
                     )
@@ -246,8 +271,9 @@ def present(name, acl_type, acl_name="", perms="", recurse=False, force=False):
             if __opts__["test"]:
                 ret.update(
                     {
-                        "comment": "New permissions will be applied for "
-                        "{0}: {1}".format(acl_name, perms),
+                        "comment": "New permissions will be applied for {}: {}".format(
+                            acl_name, perms
+                        ),
                         "result": None,
                         "changes": changes,
                     }
@@ -264,8 +290,7 @@ def present(name, acl_type, acl_name="", perms="", recurse=False, force=False):
                 )
                 ret.update(
                     {
-                        "comment": "Applied new permissions for "
-                        "{0}".format(acl_name),
+                        "comment": f"Applied new permissions for {acl_name}",
                         "result": True,
                         "changes": changes,
                     }
@@ -273,8 +298,9 @@ def present(name, acl_type, acl_name="", perms="", recurse=False, force=False):
             except CommandExecutionError as exc:
                 ret.update(
                     {
-                        "comment": "Error updating permissions for {0}: "
-                        "{1}".format(acl_name, exc.strerror),
+                        "comment": "Error updating permissions for {}: {}".format(
+                            acl_name, exc.strerror
+                        ),
                         "result": False,
                     }
                 )
@@ -308,7 +334,7 @@ def absent(name, acl_type, acl_name="", perms="", recurse=False):
     ret = {"name": name, "result": True, "changes": {}, "comment": ""}
 
     if not os.path.exists(name):
-        ret["comment"] = "{0} does not exist".format(name)
+        ret["comment"] = f"{name} does not exist"
         ret["result"] = False
         return ret
 
@@ -341,7 +367,7 @@ def absent(name, acl_type, acl_name="", perms="", recurse=False):
             user = [
                 i
                 for i in _current_perms[_acl_type]
-                if next(six.iterkeys(i)) == _search_name
+                if next(iter(i.keys())) == _search_name
             ].pop()
         except (AttributeError, IndexError, StopIteration, KeyError):
             user = None
@@ -404,9 +430,9 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
     ret = {"name": name, "result": True, "changes": {}, "comment": ""}
 
     _octal = {"r": 4, "w": 2, "x": 1, "-": 0}
-    _octal_perms = sum([_octal.get(i, i) for i in perms])
+    _octal_perms = sum(_octal.get(i, i) for i in perms)
     if not os.path.exists(name):
-        ret["comment"] = "{0} does not exist".format(name)
+        ret["comment"] = f"{name} does not exist"
         ret["result"] = False
         return ret
 
@@ -467,7 +493,7 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
         try:
             users = {}
             for i in _current_perms[_acl_type]:
-                if i and next(six.iterkeys(i)) in _search_names:
+                if i and next(iter(i.keys())) in _search_names:
                     users.update(i)
         except (AttributeError, KeyError):
             users = None
@@ -477,7 +503,7 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
             for count, search_name in enumerate(_search_names):
                 if search_name in users:
                     if users[search_name]["octal"] == sum(
-                        [_octal.get(i, i) for i in perms]
+                        _octal.get(i, i) for i in perms
                     ):
                         ret["comment"] = "Permissions are in the desired state"
                     else:
@@ -491,18 +517,20 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
                                 "old": {
                                     "acl_name": ", ".join(acl_names),
                                     "acl_type": acl_type,
-                                    "perms": six.text_type(users[search_name]["octal"]),
+                                    "perms": str(users[search_name]["octal"]),
                                 },
                             }
                         )
                         if __opts__["test"]:
                             ret.update(
                                 {
-                                    "comment": "Updated permissions will be applied for "
-                                    "{0}: {1} -> {2}".format(
-                                        acl_names,
-                                        six.text_type(users[search_name]["octal"]),
-                                        perms,
+                                    "comment": (
+                                        "Updated permissions will be applied for "
+                                        "{}: {} -> {}".format(
+                                            acl_names,
+                                            str(users[search_name]["octal"]),
+                                            perms,
+                                        )
                                     ),
                                     "result": None,
                                     "changes": changes,
@@ -526,8 +554,9 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
                                 )
                             ret.update(
                                 {
-                                    "comment": "Updated permissions for "
-                                    "{0}".format(acl_names),
+                                    "comment": "Updated permissions for {}".format(
+                                        acl_names
+                                    ),
                                     "result": True,
                                     "changes": changes,
                                 }
@@ -535,8 +564,11 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
                         except CommandExecutionError as exc:
                             ret.update(
                                 {
-                                    "comment": "Error updating permissions for "
-                                    "{0}: {1}".format(acl_names, exc.strerror),
+                                    "comment": (
+                                        "Error updating permissions for {}: {}".format(
+                                            acl_names, exc.strerror
+                                        )
+                                    ),
                                     "result": False,
                                 }
                             )
@@ -552,8 +584,11 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
                     if __opts__["test"]:
                         ret.update(
                             {
-                                "comment": "New permissions will be applied for "
-                                "{0}: {1}".format(acl_names, perms),
+                                "comment": (
+                                    "New permissions will be applied for {}: {}".format(
+                                        acl_names, perms
+                                    )
+                                ),
                                 "result": None,
                                 "changes": changes,
                             }
@@ -578,8 +613,9 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
                             )
                         ret.update(
                             {
-                                "comment": "Applied new permissions for "
-                                "{0}".format(", ".join(acl_names)),
+                                "comment": "Applied new permissions for {}".format(
+                                    ", ".join(acl_names)
+                                ),
                                 "result": True,
                                 "changes": changes,
                             }
@@ -587,8 +623,11 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
                     except CommandExecutionError as exc:
                         ret.update(
                             {
-                                "comment": "Error updating permissions for {0}: "
-                                "{1}".format(acl_names, exc.strerror),
+                                "comment": (
+                                    "Error updating permissions for {}: {}".format(
+                                        acl_names, exc.strerror
+                                    )
+                                ),
                                 "result": False,
                             }
                         )
@@ -605,8 +644,9 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
             if __opts__["test"]:
                 ret.update(
                     {
-                        "comment": "New permissions will be applied for "
-                        "{0}: {1}".format(acl_names, perms),
+                        "comment": "New permissions will be applied for {}: {}".format(
+                            acl_names, perms
+                        ),
                         "result": None,
                         "changes": changes,
                     }
@@ -629,8 +669,9 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
                     )
                 ret.update(
                     {
-                        "comment": "Applied new permissions for "
-                        "{0}".format(", ".join(acl_names)),
+                        "comment": "Applied new permissions for {}".format(
+                            ", ".join(acl_names)
+                        ),
                         "result": True,
                         "changes": changes,
                     }
@@ -638,8 +679,9 @@ def list_present(name, acl_type, acl_names=None, perms="", recurse=False, force=
             except CommandExecutionError as exc:
                 ret.update(
                     {
-                        "comment": "Error updating permissions for {0}: "
-                        "{1}".format(acl_names, exc.strerror),
+                        "comment": "Error updating permissions for {}: {}".format(
+                            acl_names, exc.strerror
+                        ),
                         "result": False,
                     }
                 )
@@ -679,7 +721,7 @@ def list_absent(name, acl_type, acl_names=None, recurse=False):
     ret = {"name": name, "result": True, "changes": {}, "comment": ""}
 
     if not os.path.exists(name):
-        ret["comment"] = "{0} does not exist".format(name)
+        ret["comment"] = f"{name} does not exist"
         ret["result"] = False
         return ret
 
@@ -710,7 +752,7 @@ def list_absent(name, acl_type, acl_names=None, recurse=False):
         try:
             users = {}
             for i in _current_perms[_acl_type]:
-                if i and next(six.iterkeys(i)) in _search_names:
+                if i and next(iter(i.keys())) in _search_names:
                     users.update(i)
         except (AttributeError, KeyError):
             users = None
