@@ -157,10 +157,10 @@ def chain_present(
         return ret
 
     if __opts__["test"]:
-        ret[
-            "comment"
-        ] = "nftables chain {} would be created in table {} for family {}".format(
-            name, table, family
+        ret["comment"] = (
+            "nftables chain {} would be created in table {} for family {}".format(
+                name, table, family
+            )
         )
         return ret
 
@@ -198,10 +198,10 @@ def chain_absent(name, table="filter", family="ipv4"):
     chain_check = __salt__["nftables.check_chain"](table, name, family)
     if not chain_check:
         ret["result"] = True
-        ret[
-            "comment"
-        ] = "nftables {} chain is already absent in {} table for {}".format(
-            name, table, family
+        ret["comment"] = (
+            "nftables {} chain is already absent in {} table for {}".format(
+                name, table, family
+            )
         )
         return ret
 
@@ -211,10 +211,10 @@ def chain_absent(name, table="filter", family="ipv4"):
         if command is True:
             ret["changes"] = {"locale": name}
             ret["result"] = True
-            ret[
-                "comment"
-            ] = "nftables {} chain in {} table delete success for {}".format(
-                name, table, family
+            ret["comment"] = (
+                "nftables {} chain in {} table delete success for {}".format(
+                    name, table, family
+                )
             )
         else:
             ret["result"] = False
@@ -287,17 +287,18 @@ def append(name, family="ipv4", **kwargs):
             if kwargs["save"]:
                 __salt__["nftables.save"](filename=None, family=family)
                 ret["comment"] = (
-                    "Set and Saved nftables rule for {} to: "
-                    "{} for {}".format(name, command.strip(), family)
+                    "Set and Saved nftables rule for {} to: {} for {}".format(
+                        name, command.strip(), family
+                    )
                 )
         return ret
     else:
         ret["result"] = False
         ret["comment"] = (
-            "Failed to set nftables rule for {}.\n"
-            "Attempted rule was {} for {}.\n"
-            "{}"
-        ).format(name, command.strip(), family, res["comment"])
+            "Failed to set nftables rule for {}.\nAttempted rule was {} for {}.\n{}".format(
+                name, command.strip(), family, res["comment"]
+            )
+        )
         return ret
 
 
@@ -361,15 +362,18 @@ def insert(name, family="ipv4", **kwargs):
             if kwargs["save"]:
                 __salt__["nftables.save"](filename=None, family=family)
                 ret["comment"] = (
-                    "Set and Saved nftables rule for {} to: "
-                    "{} for {}".format(name, command.strip(), family)
+                    "Set and Saved nftables rule for {} to: {} for {}".format(
+                        name, command.strip(), family
+                    )
                 )
         return ret
     else:
         ret["result"] = False
         ret["comment"] = (
-            "Failed to set nftables rule for {}.\n" "Attempted rule was {}"
-        ).format(name, command.strip())
+            "Failed to set nftables rule for {}.\nAttempted rule was {}".format(
+                name, command.strip()
+            )
+        )
         return ret
 
 
@@ -434,20 +438,23 @@ def delete(name, family="ipv4", **kwargs):
     if res["result"]:
         ret["changes"] = {"locale": name}
         ret["result"] = True
-        ret["comment"] = "Delete nftables rule for {} {}".format(name, command.strip())
+        ret["comment"] = f"Delete nftables rule for {name} {command.strip()}"
         if "save" in kwargs:
             if kwargs["save"]:
                 __salt__["nftables.save"](filename=None, family=family)
                 ret["comment"] = (
-                    "Deleted and Saved nftables rule for {} for {}"
-                    "{}".format(name, command.strip(), family)
+                    "Deleted and Saved nftables rule for {} for {}{}".format(
+                        name, command.strip(), family
+                    )
                 )
         return ret
     else:
         ret["result"] = False
         ret["comment"] = (
-            "Failed to delete nftables rule for {}.\n" "Attempted rule was {}"
-        ).format(name, command.strip())
+            "Failed to delete nftables rule for {}.\nAttempted rule was {}".format(
+                name, command.strip()
+            )
+        )
         return ret
 
 
@@ -485,10 +492,10 @@ def flush(name, family="ipv4", ignore_absence=False, **kwargs):
     check_table = __salt__["nftables.check_table"](kwargs["table"], family=family)
     if not ignore_absence and not check_table["result"]:
         ret["result"] = False
-        ret[
-            "comment"
-        ] = "Failed to flush table {} in family {}, table does not exist.".format(
-            kwargs["table"], family
+        ret["comment"] = (
+            "Failed to flush table {} in family {}, table does not exist.".format(
+                kwargs["table"], family
+            )
         )
         return ret
 
@@ -500,10 +507,9 @@ def flush(name, family="ipv4", ignore_absence=False, **kwargs):
         )
         if not ignore_absence and not check_chain["result"]:
             ret["result"] = False
-            ret[
-                "comment"
-            ] = "Failed to flush chain {} in table {} in family {}, chain does not exist.".format(
-                kwargs["chain"], kwargs["table"], family
+            ret["comment"] = (
+                "Failed to flush chain {} in table {} in family {}, chain does not"
+                " exist.".format(kwargs["chain"], kwargs["table"], family)
             )
             return ret
 
@@ -556,18 +562,17 @@ def set_policy(name, table="filter", family="ipv4", **kwargs):
 
     if (policy or "").lower() == kwargs["policy"].lower():
         ret["result"] = True
-        ret[
-            "comment"
-        ] = "nftables default policy for chain {} on table {} for {} already set to {}".format(
-            kwargs["chain"], table, family, kwargs["policy"]
+        ret["comment"] = (
+            "nftables default policy for chain {} on table {} for {} already set to {}".format(
+                kwargs["chain"], table, family, kwargs["policy"]
+            )
         )
         return ret
 
     if __opts__["test"]:
-        ret[
-            "comment"
-        ] = "nftables default policy for chain {} on table {} for {} needs to be set to {}".format(
-            kwargs["chain"], table, family, kwargs["policy"]
+        ret["comment"] = (
+            "nftables default policy for chain {} on table {} for {} needs to be set"
+            " to {}".format(kwargs["chain"], table, family, kwargs["policy"])
         )
         return ret
 
@@ -585,10 +590,10 @@ def set_policy(name, table="filter", family="ipv4", **kwargs):
                 __salt__["nftables.save"](
                     filename=kwargs.get("save_filename"), family=family
                 )
-                ret[
-                    "comment"
-                ] = "Set and saved default policy for {} to {} family {}".format(
-                    kwargs["chain"], kwargs["policy"], family
+                ret["comment"] = (
+                    "Set and saved default policy for {} to {} family {}".format(
+                        kwargs["chain"], kwargs["policy"], family
+                    )
                 )
     else:
         ret["result"] = False
@@ -637,7 +642,7 @@ def table_present(name, family="ipv4", **kwargs):
         )
     else:
         ret["result"] = False
-        ret["comment"] = "Failed to create table {} for family {}".format(name, family)
+        ret["comment"] = f"Failed to create table {name} for family {family}"
 
     return ret
 
@@ -682,6 +687,6 @@ def table_absent(name, family="ipv4", **kwargs):
         )
     else:
         ret["result"] = False
-        ret["comment"] = "Failed to delete table {} from family {}".format(name, family)
+        ret["comment"] = f"Failed to delete table {name} from family {family}"
 
     return ret
