@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Management of POSIX Quotas
 ==========================
@@ -12,8 +11,6 @@ The quota can be managed for the system:
         mode: off
         quotatype: user
 """
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 
 def __virtual__():
@@ -44,17 +41,17 @@ def mode(name, mode, quotatype):
         fun = "on"
     if __salt__["quota.get_mode"](name)[name][quotatype] == fun:
         ret["result"] = True
-        ret["comment"] = "Quota for {0} already set to {1}".format(name, fun)
+        ret["comment"] = f"Quota for {name} already set to {fun}"
         return ret
     if __opts__["test"]:
-        ret["comment"] = "Quota for {0} needs to be set to {1}".format(name, fun)
+        ret["comment"] = f"Quota for {name} needs to be set to {fun}"
         return ret
-    if __salt__["quota.{0}".format(fun)](name):
+    if __salt__[f"quota.{fun}"](name):
         ret["changes"] = {"quota": name}
         ret["result"] = True
-        ret["comment"] = "Set quota for {0} to {1}".format(name, fun)
+        ret["comment"] = f"Set quota for {name} to {fun}"
         return ret
     else:
         ret["result"] = False
-        ret["comment"] = "Failed to set quota for {0} to {1}".format(name, fun)
+        ret["comment"] = f"Failed to set quota for {name} to {fun}"
         return ret
