@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 Minion status monitoring
 
 Maps to the `status` execution module.
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 __monitor__ = [
     "loadavg",
@@ -30,7 +28,7 @@ def loadavg(name, maximum=None, minimum=None):
     data = __salt__["status.loadavg"]()
     if name not in data:
         ret["result"] = False
-        ret["comment"] += "Requested load average {0} not available ".format(name)
+        ret["comment"] += f"Requested load average {name} not available "
         return ret
     if minimum and maximum and minimum >= maximum:
         ret["comment"] += "Min must be less than max"
@@ -40,13 +38,13 @@ def loadavg(name, maximum=None, minimum=None):
     ret["data"] = data[name]
     if minimum:
         if cap < float(minimum):
-            ret["comment"] = "Load avg is below minimum of {0} at {1}".format(
+            ret["comment"] = "Load avg is below minimum of {} at {}".format(
                 minimum, cap
             )
             return ret
     if maximum:
         if cap > float(maximum):
-            ret["comment"] = "Load avg above maximum of {0} at {1}".format(maximum, cap)
+            ret["comment"] = f"Load avg above maximum of {maximum} at {cap}"
             return ret
     ret["comment"] = "Load avg in acceptable range"
     ret["result"] = True
@@ -71,9 +69,9 @@ def process(name):
     data = __salt__["status.pid"](name)
     if not data:
         ret["result"] = False
-        ret["comment"] += 'Process signature "{0}" not found '.format(name)
+        ret["comment"] += f'Process signature "{name}" not found '
         return ret
     ret["data"] = data
-    ret["comment"] += 'Process signature "{0}" was found '.format(name)
+    ret["comment"] += f'Process signature "{name}" was found '
     ret["result"] = True
     return ret
