@@ -180,11 +180,12 @@ according to the www policy.
         - require:
           - x509: /etc/pki/www.key
 """
+
 import base64
 import copy
-import datetime
 import logging
 import os.path
+from datetime import datetime, timedelta, timezone
 
 import salt.utils.files
 from salt.exceptions import CommandExecutionError, SaltInvocationError
@@ -389,7 +390,7 @@ def certificate_managed(
     if days_valid is None and not_after is None:
         try:
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "The default value for `days_valid` will change to 30. Please adapt your code accordingly.",
             )
             days_valid = 365
@@ -399,7 +400,7 @@ def certificate_managed(
     if days_remaining is None:
         try:
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "The default value for `days_remaining` will change to 7. Please adapt your code accordingly.",
             )
             days_remaining = 90
@@ -408,7 +409,7 @@ def certificate_managed(
 
     if "algorithm" in kwargs:
         salt.utils.versions.warn_until(
-            "Potassium",
+            3009,
             "`algorithm` has been renamed to `digest`. Please update your code.",
         )
         digest = kwargs.pop("algorithm")
@@ -433,9 +434,9 @@ def certificate_managed(
         file_managed_test = _file_managed(name, test=True, replace=False, **file_args)
         if file_managed_test["result"] is False:
             ret["result"] = False
-            ret[
-                "comment"
-            ] = "Problem while testing file.managed changes, see its output"
+            ret["comment"] = (
+                "Problem while testing file.managed changes, see its output"
+            )
             _add_sub_state_run(ret, file_managed_test)
             return ret
 
@@ -486,11 +487,16 @@ def certificate_managed(
                     else None
                 ):
                     changes["pkcs12_friendlyname"] = pkcs12_friendlyname
+                try:
+                    curr_not_after = current.not_valid_after_utc
+                except AttributeError:
+                    # naive datetime object, release <42 (it's always UTC)
+                    curr_not_after = current.not_valid_after.replace(
+                        tzinfo=timezone.utc
+                    )
 
-                if (
-                    current.not_valid_after
-                    < datetime.datetime.utcnow()
-                    + datetime.timedelta(days=days_remaining)
+                if curr_not_after < datetime.now(tz=timezone.utc) + timedelta(
+                    days=days_remaining
                 ):
                     changes["expiration"] = True
 
@@ -781,7 +787,7 @@ def crl_managed(
     if days_valid is None:
         try:
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "The default value for `days_valid` will change to 7. Please adapt your code accordingly.",
             )
             days_valid = 100
@@ -791,7 +797,7 @@ def crl_managed(
     if days_remaining is None:
         try:
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "The default value for `days_remaining` will change to 3. Please adapt your code accordingly.",
             )
             days_remaining = 30
@@ -803,14 +809,14 @@ def crl_managed(
         parsed = {}
         if len(rev) == 1 and isinstance(rev[next(iter(rev))], list):
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "Revoked certificates should be specified as a simple list of dicts.",
             )
             for val in rev[next(iter(rev))]:
                 parsed.update(val)
         if "reason" in (parsed or rev):
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "The `reason` parameter for revoked certificates should be specified in extensions:CRLReason.",
             )
             salt.utils.dictupdate.set_dict_key_value(
@@ -839,9 +845,9 @@ def crl_managed(
 
         if file_managed_test["result"] is False:
             ret["result"] = False
-            ret[
-                "comment"
-            ] = "Problem while testing file.managed changes, see its output"
+            ret["comment"] = (
+                "Problem while testing file.managed changes, see its output"
+            )
             _add_sub_state_run(ret, file_managed_test)
             return ret
 
@@ -895,10 +901,14 @@ def crl_managed(
 
                 if encoding != current_encoding:
                     changes["encoding"] = encoding
+                try:
+                    curr_next_update = current.next_update_utc
+                except AttributeError:
+                    # naive datetime object, release <42 (it's always UTC)
+                    curr_next_update = current.next_update.replace(tzinfo=timezone.utc)
                 if days_remaining and (
-                    current.next_update
-                    < datetime.datetime.utcnow()
-                    + datetime.timedelta(days=days_remaining)
+                    curr_next_update
+                    < datetime.now(tz=timezone.utc) + timedelta(days=days_remaining)
                 ):
                     changes["expiration"] = True
 
@@ -1055,7 +1065,7 @@ def csr_managed(
     # Deprecation checks vs the old x509 module
     if "algorithm" in kwargs:
         salt.utils.versions.warn_until(
-            "Potassium",
+            3009,
             "`algorithm` has been renamed to `digest`. Please update your code.",
         )
         digest = kwargs.pop("algorithm")
@@ -1078,9 +1088,9 @@ def csr_managed(
 
         if file_managed_test["result"] is False:
             ret["result"] = False
-            ret[
-                "comment"
-            ] = "Problem while testing file.managed changes, see its output"
+            ret["comment"] = (
+                "Problem while testing file.managed changes, see its output"
+            )
             _add_sub_state_run(ret, file_managed_test)
             return ret
 
@@ -1322,7 +1332,7 @@ def private_key_managed(
     # Deprecation checks vs the old x509 module
     if "bits" in kwargs:
         salt.utils.versions.warn_until(
-            "Potassium",
+            3009,
             "`bits` has been renamed to `keysize`. Please update your code.",
         )
         keysize = kwargs.pop("bits")
@@ -1362,9 +1372,9 @@ def private_key_managed(
 
         if file_managed_test["result"] is False:
             ret["result"] = False
-            ret[
-                "comment"
-            ] = "Problem while testing file.managed changes, see its output"
+            ret["comment"] = (
+                "Problem while testing file.managed changes, see its output"
+            )
             _add_sub_state_run(ret, file_managed_test)
             return ret
 
@@ -1584,9 +1594,9 @@ def _file_managed(name, test=None, **kwargs):
 def _check_file_ret(fret, ret, current):
     if fret["result"] is False:
         ret["result"] = False
-        ret[
-            "comment"
-        ] = f"Could not {'create' if not current else 'update'} file, see file.managed output"
+        ret["comment"] = (
+            f"Could not {'create' if not current else 'update'} file, see file.managed output"
+        )
         ret["changes"] = {}
         return False
     return True
