@@ -1,17 +1,12 @@
-# -*- coding: utf-8 -*-
 """
 Compatibility functions for utils
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import copy
 import importlib
 import sys
 import types
 
-# Import salt libs
 import salt.loader
 
 
@@ -23,7 +18,9 @@ def pack_dunder(name):
 
     mod = sys.modules[name]
     if not hasattr(mod, "__utils__"):
-        setattr(mod, "__utils__", salt.loader.utils(mod.__opts__))
+        setattr(
+            mod, "__utils__", salt.loader.utils(mod.__opts__, pack_self="__utils__")
+        )
 
 
 def deepcopy_bound(name):
@@ -41,12 +38,10 @@ def deepcopy_bound(name):
     """
 
     def _deepcopy_method(x, memo):
-        # pylint: disable=incompatible-py3-code
         return type(x)(x.im_func, copy.deepcopy(x.im_self, memo), x.im_class)
-        # pylint: enable=incompatible-py3-code
 
+    pre_dispatch = copy._deepcopy_dispatch
     try:
-        pre_dispatch = copy._deepcopy_dispatch
         copy._deepcopy_dispatch[types.MethodType] = _deepcopy_method
         ret = copy.deepcopy(name)
     finally:
@@ -63,6 +58,8 @@ def cmp(x, y):
 
     Return negative if x<y, zero if x==y, positive if x>y.
     """
+    if isinstance(x, dict) and isinstance(y, dict):
+        return 0 if x == y else -1
     return (x > y) - (x < y)
 
 
