@@ -1,6 +1,7 @@
 """
 Functions dealing with encryption
 """
+
 import hashlib
 import logging
 import os
@@ -111,9 +112,7 @@ def decrypt(
 
     rend_func = renderers.get(rend)
     if rend_func is None:
-        raise SaltInvocationError(
-            "Decryption renderer '{}' is not available".format(rend)
-        )
+        raise SaltInvocationError(f"Decryption renderer '{rend}' is not available")
 
     return rend_func(data, translate_newlines=translate_newlines)
 
@@ -159,7 +158,7 @@ def pem_finger(path=None, key=None, sum_type="sha256"):
     for ind, _ in enumerate(pre):
         if ind % 2:
             # Is odd
-            finger += "{}:".format(pre[ind])
+            finger += f"{pre[ind]}:"
         else:
             finger += pre[ind]
     return finger.rstrip(":")
