@@ -49,9 +49,11 @@ Namespaced tag
 
 """
 
+import asyncio
 import atexit
 import contextlib
 import datetime
+import errno
 import fnmatch
 import hashlib
 import logging
@@ -59,14 +61,13 @@ import os
 import time
 from collections.abc import MutableMapping
 
+import tornado.ioloop
+import tornado.iostream
+
+import salt.channel.client
 import salt.config
 import salt.defaults.exitcodes
-import salt.ext.tornado.ioloop
-import salt.ext.tornado.iostream
-import salt.log.setup
 import salt.payload
-import salt.transport.client
-import salt.transport.ipc
 import salt.utils.asynchronous
 import salt.utils.cache
 import salt.utils.dicttrim
@@ -75,6 +76,7 @@ import salt.utils.platform
 import salt.utils.process
 import salt.utils.stringutils
 import salt.utils.zeromq
+from salt.utils.versions import warn_until
 
 log = logging.getLogger(__name__)
 
@@ -105,7 +107,6 @@ TAGS = {
 def get_event(
     node,
     sock_dir=None,
-    transport="zeromq",
     opts=None,
     listen=True,
     io_loop=None,
@@ -146,11 +147,9 @@ def get_master_event(opts, sock_dir, listen=True, io_loop=None, raise_errors=Fal
     """
     Return an event object suitable for the named transport
     """
-    # TODO: AIO core is separate from transport
-    if opts["transport"] in ("zeromq", "tcp", "detect"):
-        return MasterEvent(
-            sock_dir, opts, listen=listen, io_loop=io_loop, raise_errors=raise_errors
-        )
+    return MasterEvent(
+        sock_dir, opts, listen=listen, io_loop=io_loop, raise_errors=raise_errors
+    )
 
 
 def fire_args(opts, jid, tag_data, prefix=""):
@@ -226,13 +225,13 @@ class SaltEvent:
                                is destroyed. This is useful when using event
                                loops from within third party asynchronous code
         """
-        self.serial = salt.payload.Serial({"serial": "msgpack"})
+        self.node = node
         self.keep_loop = keep_loop
         if io_loop is not None:
             self.io_loop = io_loop
             self._run_io_loop_sync = False
         else:
-            self.io_loop = salt.ext.tornado.ioloop.IOLoop()
+            self.io_loop = None
             self._run_io_loop_sync = True
         self.cpub = False
         self.cpush = False
@@ -255,7 +254,6 @@ class SaltEvent:
 
         if salt.utils.platform.is_windows() and "ipc_mode" not in opts:
             self.opts["ipc_mode"] = "tcp"
-        self.puburi, self.pulluri = self.__load_uri(sock_dir, node)
         self.pending_tags = []
         self.pending_events = []
         self.__load_cache_regex()
@@ -278,40 +276,6 @@ class SaltEvent:
         # the default 'startswith' and the optional 'regex' match_type
         cls.cache_regex = salt.utils.cache.CacheRegex(prepend="^")
 
-    def __load_uri(self, sock_dir, node):
-        """
-        Return the string URI for the location of the pull and pub sockets to
-        use for firing and listening to events
-        """
-        if node == "master":
-            if self.opts["ipc_mode"] == "tcp":
-                puburi = int(self.opts["tcp_master_pub_port"])
-                pulluri = int(self.opts["tcp_master_pull_port"])
-            else:
-                puburi = os.path.join(sock_dir, "master_event_pub.ipc")
-                pulluri = os.path.join(sock_dir, "master_event_pull.ipc")
-        else:
-            if self.opts["ipc_mode"] == "tcp":
-                puburi = int(self.opts["tcp_pub_port"])
-                pulluri = int(self.opts["tcp_pull_port"])
-            else:
-                hash_type = getattr(hashlib, self.opts["hash_type"])
-                # Only use the first 10 chars to keep longer hashes from exceeding the
-                # max socket path length.
-                minion_id = self.opts.get("hash_id", self.opts["id"])
-                id_hash = hash_type(
-                    salt.utils.stringutils.to_bytes(minion_id)
-                ).hexdigest()[:10]
-                puburi = os.path.join(
-                    sock_dir, "minion_event_{}_pub.ipc".format(id_hash)
-                )
-                pulluri = os.path.join(
-                    sock_dir, "minion_event_{}_pull.ipc".format(id_hash)
-                )
-        log.debug("%s PUB socket URI: %s", self.__class__.__name__, puburi)
-        log.debug("%s PULL socket URI: %s", self.__class__.__name__, pulluri)
-        return puburi, pulluri
-
     def subscribe(self, tag=None, match_type=None):
         """
         Subscribe to events matching the passed tag.
@@ -354,26 +318,37 @@ class SaltEvent:
         """
         if self.cpub:
             return True
-
         if self._run_io_loop_sync:
-            with salt.utils.asynchronous.current_ioloop(self.io_loop):
-                if self.subscriber is None:
-                    self.subscriber = salt.utils.asynchronous.SyncWrapper(
-                        salt.transport.ipc.IPCMessageSubscriber,
-                        args=(self.puburi,),
-                        kwargs={"io_loop": self.io_loop},
-                        loop_kwarg="io_loop",
-                    )
-                try:
-                    self.subscriber.connect(timeout=timeout)
-                    self.cpub = True
-                except Exception:  # pylint: disable=broad-except
-                    pass
+            if self.subscriber is None:
+                self.subscriber = salt.utils.asynchronous.SyncWrapper(
+                    salt.transport.ipc_publish_client,
+                    args=(
+                        self.node,
+                        self.opts,
+                    ),
+                    loop_kwarg="io_loop",
+                )
+            try:
+                self.subscriber.connect(timeout=timeout)
+                self.cpub = True
+            except tornado.iostream.StreamClosedError:
+                log.error("Encountered StreamClosedException")
+            except OSError as exc:
+                if exc.errno != errno.ENOENT:
+                    raise
+                log.error("Error opening stream, file does not exist")
+            except Exception as exc:  # pylint: disable=broad-except
+                log.info(
+                    "An exception occurred connecting publisher: %s",
+                    exc,
+                    exc_info_on_loglevel=logging.DEBUG,
+                )
         else:
             if self.subscriber is None:
-                self.subscriber = salt.transport.ipc.IPCMessageSubscriber(
-                    self.puburi, io_loop=self.io_loop
+                self.subscriber = salt.transport.ipc_publish_client(
+                    self.node, self.opts, io_loop=self.io_loop
                 )
+                self.io_loop.spawn_callback(self.subscriber.connect)
 
             # For the asynchronous case, the connect will be defered to when
             # set_event_handler() is invoked.
@@ -386,7 +361,6 @@ class SaltEvent:
         """
         if not self.cpub:
             return
-
         self.subscriber.close()
         self.subscriber = None
         self.pending_events = []
@@ -401,23 +375,30 @@ class SaltEvent:
             return True
 
         if self._run_io_loop_sync:
-            with salt.utils.asynchronous.current_ioloop(self.io_loop):
-                if self.pusher is None:
-                    self.pusher = salt.utils.asynchronous.SyncWrapper(
-                        salt.transport.ipc.IPCMessageClient,
-                        args=(self.pulluri,),
-                        kwargs={"io_loop": self.io_loop},
-                        loop_kwarg="io_loop",
-                    )
-                try:
-                    self.pusher.connect(timeout=timeout)
-                    self.cpush = True
-                except Exception:  # pylint: disable=broad-except
-                    pass
+            if self.pusher is None:
+                self.pusher = salt.utils.asynchronous.SyncWrapper(
+                    salt.transport.ipc_publish_server,
+                    args=(
+                        self.node,
+                        self.opts,
+                    ),
+                )
+            try:
+                self.pusher.connect(timeout=timeout)
+                self.cpush = True
+            except tornado.iostream.StreamClosedError as exc:
+                log.debug("Unable to connect pusher: %s", exc)
+            except Exception as exc:  # pylint: disable=broad-except
+                log.error(
+                    "Unable to connect pusher: %s",
+                    exc,
+                    exc_info_on_loglevel=logging.DEBUG,
+                )
         else:
             if self.pusher is None:
-                self.pusher = salt.transport.ipc.IPCMessageClient(
-                    self.pulluri, io_loop=self.io_loop
+                self.pusher = salt.transport.ipc_publish_server(
+                    self.node,
+                    self.opts,
                 )
             # For the asynchronous case, the connect will be deferred to when
             # fire_event() is invoked.
@@ -430,27 +411,42 @@ class SaltEvent:
         """
         if not self.cpush:
             return
-
         self.pusher.close()
         self.pusher = None
         self.cpush = False
 
     @classmethod
-    def unpack(cls, raw, serial=None):
-        if serial is None:
-            serial = salt.payload.Serial({"serial": "msgpack"})
-
+    def unpack(cls, raw):
         mtag, sep, mdata = raw.partition(
             salt.utils.stringutils.to_bytes(TAGEND)
         )  # split tag from data
         mtag = salt.utils.stringutils.to_str(mtag)
-        data = serial.loads(mdata, encoding="utf-8")
+        data = salt.payload.loads(mdata, encoding="utf-8")
         return mtag, data
 
+    @classmethod
+    def pack(cls, tag, data, max_size=None):
+        tagend = TAGEND
+        serialized_data = salt.payload.dumps(data, use_bin_type=True)
+        if max_size:
+            serialized_data = salt.utils.dicttrim.trim_dict(
+                serialized_data,
+                max_size,
+                is_msgpacked=True,
+                use_bin_type=True,
+            )
+        return b"".join(
+            [
+                salt.utils.stringutils.to_bytes(tag),
+                salt.utils.stringutils.to_bytes(tagend),
+                serialized_data,
+            ]
+        )
+
     def _get_match_func(self, match_type=None):
         if match_type is None:
             match_type = self.opts["event_match_type"]
-        return getattr(self, "_match_tag_{}".format(match_type), None)
+        return getattr(self, f"_match_tag_{match_type}", None)
 
     def _check_pending(self, tag, match_func=None):
         """Check the pending_events list for events that match the tag
@@ -479,7 +475,8 @@ class SaltEvent:
                 self.pending_events.append(evt)
             else:
                 log.trace(
-                    "get_event() discarding cached event that no longer has any subscriptions = %s",
+                    "get_event() discarding cached event that no longer has any"
+                    " subscriptions = %s",
                     evt,
                 )
         return ret
@@ -553,14 +550,14 @@ class SaltEvent:
             try:
                 if not self.cpub and not self.connect_pub(timeout=wait):
                     break
-                raw = self.subscriber.read(timeout=wait)
+                raw = self.subscriber.recv(timeout=wait)
                 if raw is None:
                     break
-                mtag, data = self.unpack(raw, self.serial)
+                mtag, data = self.unpack(raw)
                 ret = {"data": data, "tag": mtag}
             except KeyboardInterrupt:
                 return {"tag": "salt/event/exit", "data": {}}
-            except salt.ext.tornado.iostream.StreamClosedError:
+            except tornado.iostream.StreamClosedError:
                 if self.raise_errors:
                     raise
                 else:
@@ -646,21 +643,20 @@ class SaltEvent:
 
         ret = self._check_pending(tag, match_func)
         if ret is None:
-            with salt.utils.asynchronous.current_ioloop(self.io_loop):
-                if auto_reconnect:
-                    raise_errors = self.raise_errors
-                    self.raise_errors = True
-                    while True:
-                        try:
-                            ret = self._get_event(wait, tag, match_func, no_block)
-                            break
-                        except salt.ext.tornado.iostream.StreamClosedError:
-                            self.close_pub()
-                            self.connect_pub(timeout=wait)
-                            continue
-                    self.raise_errors = raise_errors
-                else:
-                    ret = self._get_event(wait, tag, match_func, no_block)
+            if auto_reconnect:
+                raise_errors = self.raise_errors
+                self.raise_errors = True
+                while True:
+                    try:
+                        ret = self._get_event(wait, tag, match_func, no_block)
+                        break
+                    except tornado.iostream.StreamClosedError:
+                        self.close_pub()
+                        self.connect_pub(timeout=wait)
+                        continue
+                self.raise_errors = raise_errors
+            else:
+                ret = self._get_event(wait, tag, match_func, no_block)
 
         if ret is None or full:
             return ret
@@ -676,10 +672,10 @@ class SaltEvent:
         if not self.cpub:
             if not self.connect_pub():
                 return None
-        raw = self.subscriber._read(timeout=0)
+        raw = self.subscriber.recv(timeout=0)
         if raw is None:
             return None
-        mtag, data = self.unpack(raw, self.serial)
+        mtag, data = self.unpack(raw)
         return {"data": data, "tag": mtag}
 
     def get_event_block(self):
@@ -692,10 +688,10 @@ class SaltEvent:
         if not self.cpub:
             if not self.connect_pub():
                 return None
-        raw = self.subscriber._read(timeout=None)
+        raw = self.subscriber.recv(timeout=None)
         if raw is None:
             return None
-        mtag, data = self.unpack(raw, self.serial)
+        mtag, data = self.unpack(raw)
         return {"data": data, "tag": mtag}
 
     def iter_events(self, tag="", full=False, match_type=None, auto_reconnect=False):
@@ -710,8 +706,7 @@ class SaltEvent:
                 continue
             yield data
 
-    @salt.ext.tornado.gen.coroutine
-    def fire_event_async(self, data, tag, cb=None, timeout=1000):
+    async def fire_event_async(self, data, tag, cb=None, timeout=1000):
         """
         Send a single event into the publisher with payload dict "data" and
         event identifier "tag"
@@ -725,7 +720,7 @@ class SaltEvent:
             raise ValueError("Empty tag.")
 
         if not isinstance(data, MutableMapping):  # data must be dict
-            raise ValueError("Dict object expected, not '{}'.".format(data))
+            raise ValueError(f"Dict object expected, not '{data}'.")
 
         if not self.cpush:
             if timeout is not None:
@@ -736,32 +731,15 @@ class SaltEvent:
                 return False
 
         data["_stamp"] = datetime.datetime.utcnow().isoformat()
-
-        tagend = TAGEND
-        # Since the pack / unpack logic here is for local events only,
-        # it is safe to change the wire protocol. The mechanism
-        # that sends events from minion to master is outside this
-        # file.
-        dump_data = self.serial.dumps(data, use_bin_type=True)
-
-        serialized_data = salt.utils.dicttrim.trim_dict(
-            dump_data,
-            self.opts["max_event_size"],
-            is_msgpacked=True,
-            use_bin_type=True,
-        )
-        log.debug("Sending event: tag = %s; data = %s", tag, data)
-        event = b"".join(
-            [
-                salt.utils.stringutils.to_bytes(tag),
-                salt.utils.stringutils.to_bytes(tagend),
-                serialized_data,
-            ]
-        )
+        event = self.pack(tag, data, max_size=self.opts["max_event_size"])
         msg = salt.utils.stringutils.to_bytes(event, "utf-8")
-        ret = yield self.pusher.send(msg)
+        self.pusher.publish(msg)
         if cb is not None:
-            cb(ret)
+            warn_until(
+                3008,
+                "The cb argument to fire_event_async will be removed in 3008",
+            )
+            cb(None)
 
     def fire_event(self, data, tag, timeout=1000):
         """
@@ -777,7 +755,7 @@ class SaltEvent:
             raise ValueError("Empty tag.")
 
         if not isinstance(data, MutableMapping):  # data must be dict
-            raise ValueError("Dict object expected, not '{}'.".format(data))
+            raise ValueError(f"Dict object expected, not '{data}'.")
 
         if not self.cpush:
             if timeout is not None:
@@ -788,38 +766,20 @@ class SaltEvent:
                 return False
 
         data["_stamp"] = datetime.datetime.utcnow().isoformat()
-
-        tagend = TAGEND
-        # Since the pack / unpack logic here is for local events only,
-        # it is safe to change the wire protocol. The mechanism
-        # that sends events from minion to master is outside this
-        # file.
-        dump_data = self.serial.dumps(data, use_bin_type=True)
-
-        serialized_data = salt.utils.dicttrim.trim_dict(
-            dump_data,
-            self.opts["max_event_size"],
-            is_msgpacked=True,
-            use_bin_type=True,
-        )
-        log.debug("Sending event: tag = %s; data = %s", tag, data)
-        event = b"".join(
-            [
-                salt.utils.stringutils.to_bytes(tag),
-                salt.utils.stringutils.to_bytes(tagend),
-                serialized_data,
-            ]
-        )
+        event = self.pack(tag, data, max_size=self.opts["max_event_size"])
         msg = salt.utils.stringutils.to_bytes(event, "utf-8")
         if self._run_io_loop_sync:
-            with salt.utils.asynchronous.current_ioloop(self.io_loop):
-                try:
-                    self.pusher.send(msg)
-                except Exception as ex:  # pylint: disable=broad-except
-                    log.debug(ex)
-                    raise
+            try:
+                self.pusher.publish(msg)
+            except Exception as exc:  # pylint: disable=broad-except
+                log.debug(
+                    "Publisher send failed with exception: %s",
+                    exc,
+                    exc_info_on_loglevel=logging.DEBUG,
+                )
+                raise
         else:
-            self.io_loop.spawn_callback(self.pusher.send, msg)
+            asyncio.create_task(self.pusher.publish(msg))
         return True
 
     def fire_master(self, data, tag, timeout=1000):
@@ -837,8 +797,6 @@ class SaltEvent:
             self.close_pub()
         if self.pusher is not None:
             self.close_pull()
-        if self._run_io_loop_sync and not self.keep_loop:
-            self.io_loop.close()
 
     def _fire_ret_load_specific_fun(self, load, fun_index=0):
         """
@@ -872,21 +830,24 @@ class SaltEvent:
                 data["retcode"] = retcode
                 tags = tag.split("_|-")
                 if data.get("result") is False:
-                    self.fire_event(
-                        data, "{}.{}".format(tags[0], tags[-1])
-                    )  # old dup event
+                    self.fire_event(data, f"{tags[0]}.{tags[-1]}")  # old dup event
                     data["jid"] = load["jid"]
                     data["id"] = load["id"]
                     data["success"] = False
-                    data["return"] = "Error: {}.{}".format(tags[0], tags[-1])
+                    data["return"] = f"Error: {tags[0]}.{tags[-1]}"
                     data["fun"] = fun
-                    data["user"] = load["user"]
+                    if "user" in load:
+                        data["user"] = load["user"]
                     self.fire_event(
                         data,
                         tagify([load["jid"], "sub", load["id"], "error", fun], "job"),
                     )
-        except Exception:  # pylint: disable=broad-except
-            pass
+        except Exception as exc:  # pylint: disable=broad-except
+            log.error(
+                "Event iteration failed with exception: %s",
+                exc,
+                exc_info_on_loglevel=logging.DEBUG,
+            )
 
     def fire_ret_load(self, load):
         """
@@ -925,11 +886,10 @@ class SaltEvent:
         Invoke the event_handler callback each time an event arrives.
         """
         assert not self._run_io_loop_sync
-
         if not self.cpub:
             self.connect_pub()
         # This will handle reconnects
-        return self.subscriber.read_async(event_handler)
+        self.io_loop.spawn_callback(self.subscriber.on_recv, event_handler)
 
     # pylint: disable=W1701
     def __del__(self):
@@ -1036,11 +996,18 @@ class AsyncEventPublisher:
     """
 
     def __init__(self, opts, io_loop=None):
+        warn_until(
+            3008,
+            "salt.utils.event.AsyncEventPublisher is deprecated. "
+            "Please use salt.transport.publish_server instead.",
+        )
+        import salt.transport.ipc
+
         self.opts = salt.config.DEFAULT_MINION_OPTS.copy()
         default_minion_sock_dir = self.opts["sock_dir"]
         self.opts.update(opts)
 
-        self.io_loop = io_loop or salt.ext.tornado.ioloop.IOLoop.current()
+        self.io_loop = io_loop or tornado.ioloop.IOLoop.current()
         self._closing = False
         self.publisher = None
         self.puller = None
@@ -1052,12 +1019,12 @@ class AsyncEventPublisher:
             salt.utils.stringutils.to_bytes(self.opts["id"])
         ).hexdigest()[:10]
         epub_sock_path = os.path.join(
-            self.opts["sock_dir"], "minion_event_{}_pub.ipc".format(id_hash)
+            self.opts["sock_dir"], f"minion_event_{id_hash}_pub.ipc"
         )
         if os.path.exists(epub_sock_path):
             os.unlink(epub_sock_path)
         epull_sock_path = os.path.join(
-            self.opts["sock_dir"], "minion_event_{}_pull.ipc".format(id_hash)
+            self.opts["sock_dir"], f"minion_event_{id_hash}_pull.ipc"
         )
         if os.path.exists(epull_sock_path):
             os.unlink(epull_sock_path)
@@ -1136,6 +1103,11 @@ class EventPublisher(salt.utils.process.SignalHandlingProcess):
     """
 
     def __init__(self, opts, **kwargs):
+        warn_until(
+            3008,
+            "salt.utils.event.EventPublisher is deprecated. "
+            "Please use salt.transport.publish_server instead.",
+        )
         super().__init__(**kwargs)
         self.opts = salt.config.DEFAULT_MASTER_OPTS.copy()
         self.opts.update(opts)
@@ -1144,28 +1116,11 @@ class EventPublisher(salt.utils.process.SignalHandlingProcess):
         self.puller = None
         self.publisher = None
 
-    # __setstate__ and __getstate__ are only used on Windows.
-    # We do this so that __init__ will be invoked on Windows in the child
-    # process so that a register_after_fork() equivalent will work on Windows.
-    def __setstate__(self, state):
-        self.__init__(
-            state["opts"],
-            log_queue=state["log_queue"],
-            log_queue_level=state["log_queue_level"],
-        )
-
-    def __getstate__(self):
-        return {
-            "opts": self.opts,
-            "log_queue": self.log_queue,
-            "log_queue_level": self.log_queue_level,
-        }
-
     def run(self):
         """
         Bind the pub and pull sockets for events
         """
-        salt.utils.process.appendproctitle(self.__class__.__name__)
+        import salt.transport.ipc
 
         if (
             self.opts["event_publisher_niceness"]
@@ -1177,7 +1132,7 @@ class EventPublisher(salt.utils.process.SignalHandlingProcess):
             )
             os.nice(self.opts["event_publisher_niceness"])
 
-        self.io_loop = salt.ext.tornado.ioloop.IOLoop()
+        self.io_loop = tornado.ioloop.IOLoop()
         with salt.utils.asynchronous.current_ioloop(self.io_loop):
             if self.opts["ipc_mode"] == "tcp":
                 epub_uri = int(self.opts["tcp_master_pub_port"])
@@ -1191,7 +1146,9 @@ class EventPublisher(salt.utils.process.SignalHandlingProcess):
             )
 
             self.puller = salt.transport.ipc.IPCMessageServer(
-                epull_uri, io_loop=self.io_loop, payload_handler=self.handle_publish,
+                epull_uri,
+                io_loop=self.io_loop,
+                payload_handler=self.handle_publish,
             )
 
             # Start the master event publisher
@@ -1203,7 +1160,7 @@ class EventPublisher(salt.utils.process.SignalHandlingProcess):
                 ):
                     os.chmod(  # nosec
                         os.path.join(self.opts["sock_dir"], "master_event_pub.ipc"),
-                        0o666,
+                        0o660,
                     )
 
             atexit.register(self.close)
@@ -1275,23 +1232,6 @@ class EventReturn(salt.utils.process.SignalHandlingProcess):
         self.event_queue = []
         self.stop = False
 
-    # __setstate__ and __getstate__ are only used on Windows.
-    # We do this so that __init__ will be invoked on Windows in the child
-    # process so that a register_after_fork() equivalent will work on Windows.
-    def __setstate__(self, state):
-        self.__init__(
-            state["opts"],
-            log_queue=state["log_queue"],
-            log_queue_level=state["log_queue_level"],
-        )
-
-    def __getstate__(self):
-        return {
-            "opts": self.opts,
-            "log_queue": self.log_queue,
-            "log_queue_level": self.log_queue_level,
-        }
-
     def _handle_signals(self, signum, sigframe):
         # Flush and terminate
         if self.event_queue:
@@ -1304,7 +1244,7 @@ class EventReturn(salt.utils.process.SignalHandlingProcess):
             # Multiple event returners
             for r in self.opts["event_return"]:
                 log.debug("Calling event returner %s, one of many.", r)
-                event_return = "{}.event_return".format(r)
+                event_return = f"{r}.event_return"
                 self._flush_event_single(event_return)
         else:
             # Only a single event returner
@@ -1322,7 +1262,7 @@ class EventReturn(salt.utils.process.SignalHandlingProcess):
                 self.minion.returners[event_return](self.event_queue)
             except Exception as exc:  # pylint: disable=broad-except
                 log.error(
-                    "Could not store events - returner '%s' raised " "exception: %s",
+                    "Could not store events - returner '%s' raised exception: %s",
                     event_return,
                     exc,
                 )
@@ -1334,7 +1274,7 @@ class EventReturn(salt.utils.process.SignalHandlingProcess):
                     )
         else:
             log.error(
-                "Could not store return for event(s) - returner " "'%s' not found.",
+                "Could not store return for event(s) - returner '%s' not found.",
                 event_return,
             )
 
@@ -1342,8 +1282,6 @@ class EventReturn(salt.utils.process.SignalHandlingProcess):
         """
         Spin up the multiprocess event returner
         """
-        salt.utils.process.appendproctitle(self.__class__.__name__)
-
         if self.opts["event_return_niceness"] and not salt.utils.platform.is_windows():
             log.info(
                 "setting EventReturn niceness to %i", self.opts["event_return_niceness"]
@@ -1361,7 +1299,11 @@ class EventReturn(salt.utils.process.SignalHandlingProcess):
                 if event["tag"] == "salt/event/exit":
                     # We're done eventing
                     self.stop = True
-                if self._filter(event):
+                if self._filter(
+                    event,
+                    allow=self.opts["event_return_whitelist"],
+                    deny=self.opts["event_return_blacklist"],
+                ):
                     # This event passed the filter, add it to the queue
                     self.event_queue.append(event)
                 too_long_in_queue = False
@@ -1409,23 +1351,40 @@ class EventReturn(salt.utils.process.SignalHandlingProcess):
 
                 self.flush_events()
 
-    def _filter(self, event):
+    @staticmethod
+    def _filter(event, allow=None, deny=None):
         """
         Take an event and run it through configured filters.
 
-        Returns True if event should be stored, else False
+        Returns True if event should be stored, else False.
+
+        Any event that has a "__peer_id" id key defined are denied outright
+        because they did not originate from this master in a clustered
+        configuration.
+
+        If no allow or deny lists are given the event is allowed. Otherwise the
+        event's tag will be checked against the allow list. Then the deny list.
         """
+
+        if "__peer_id" in event:
+            return False
+
+        if allow is None:
+            allow = []
+        if deny is None:
+            deny = []
         tag = event["tag"]
-        if self.opts["event_return_whitelist"]:
+
+        if allow:
             ret = False
         else:
             ret = True
-        for whitelist_match in self.opts["event_return_whitelist"]:
-            if fnmatch.fnmatch(tag, whitelist_match):
+        for allow_match in allow:
+            if fnmatch.fnmatch(tag, allow_match):
                 ret = True
                 break
-        for blacklist_match in self.opts["event_return_blacklist"]:
-            if fnmatch.fnmatch(tag, blacklist_match):
+        for deny_match in deny:
+            if fnmatch.fnmatch(tag, deny_match):
                 ret = False
                 break
         return ret
@@ -1469,7 +1428,7 @@ class StateFire:
             }
         )
 
-        with salt.transport.client.ReqChannel.factory(self.opts) as channel:
+        with salt.channel.client.ReqChannel.factory(self.opts) as channel:
             try:
                 channel.send(load)
             except Exception as exc:  # pylint: disable=broad-except
@@ -1497,7 +1456,7 @@ class StateFire:
                 "True" if running[stag]["changes"] else "False",
             )
             load["events"].append({"tag": tag, "data": running[stag]})
-        with salt.transport.client.ReqChannel.factory(self.opts) as channel:
+        with salt.channel.client.ReqChannel.factory(self.opts) as channel:
             try:
                 channel.send(load)
             except Exception as exc:  # pylint: disable=broad-except
