@@ -22,9 +22,12 @@ import urllib.request
 import xml.etree.ElementTree as ET
 import zlib
 
+import tornado.httpclient
+import tornado.httputil
+import tornado.simple_httpclient
+from tornado.httpclient import HTTPClient
+
 import salt.config
-import salt.ext.tornado.httputil
-import salt.ext.tornado.simple_httpclient
 import salt.loader
 import salt.syspaths
 import salt.utils.args
@@ -39,7 +42,6 @@ import salt.utils.url
 import salt.utils.xmlutil as xml
 import salt.utils.yaml
 import salt.version
-from salt.ext.tornado.httpclient import HTTPClient
 from salt.template import compile_template
 from salt.utils.decorators.jinja import jinja_filter
 
@@ -268,7 +270,7 @@ def query(
 
     # Some libraries don't support separation of url and GET parameters
     # Don't need a try/except block, since Salt depends on tornado
-    url_full = salt.ext.tornado.httputil.url_concat(url, params) if params else url
+    url_full = tornado.httputil.url_concat(url, params) if params else url
 
     if ca_bundle is None:
         ca_bundle = get_ca_bundle(opts)
@@ -353,6 +355,19 @@ def query(
         agent = f"{agent} http.query()"
     header_dict["User-agent"] = agent
 
+    if (
+        proxy_host
+        and proxy_port
+        and method == "POST"
+        and "Content-Type" not in header_dict
+    ):
+        log.debug(
+            "Content-Type not provided for POST request, assuming application/x-www-form-urlencoded"
+        )
+        header_dict["Content-Type"] = "application/x-www-form-urlencoded"
+        if "Content-Length" not in header_dict:
+            header_dict["Content-Length"] = f"{len(data)}"
+
     if backend == "requests":
         sess = requests.Session()
         sess.auth = auth
@@ -485,10 +500,10 @@ def query(
                 try:
                     match_hostname(sockwrap.getpeercert(), hostname)
                 except CertificateError as exc:
-                    ret[
-                        "error"
-                    ] = "The certificate was invalid. Error returned was: {}".format(
-                        pprint.pformat(exc)
+                    ret["error"] = (
+                        "The certificate was invalid. Error returned was: {}".format(
+                            pprint.pformat(exc)
+                        )
                     )
                     return ret
 
@@ -583,9 +598,9 @@ def query(
             salt.config.DEFAULT_MINION_OPTS["http_request_timeout"],
         )
 
-        salt.ext.tornado.httpclient.AsyncHTTPClient.configure(None)
+        tornado.httpclient.AsyncHTTPClient.configure(None)
         client_argspec = salt.utils.args.get_function_argspec(
-            salt.ext.tornado.simple_httpclient.SimpleAsyncHTTPClient.initialize
+            tornado.simple_httpclient.SimpleAsyncHTTPClient.initialize
         )
 
         supports_max_body_size = "max_body_size" in client_argspec.args
@@ -620,7 +635,7 @@ def query(
                 else HTTPClient()
             )
             result = download_client.fetch(url_full, **req_kwargs)
-        except salt.ext.tornado.httpclient.HTTPError as exc:
+        except tornado.httpclient.HTTPError as exc:
             ret["status"] = exc.code
             ret["error"] = str(exc)
             ret["body"], _ = _decode_result(
@@ -725,10 +740,10 @@ def query(
 
         valid_decodes = ("json", "xml", "yaml", "plain")
         if decode_type not in valid_decodes:
-            ret[
-                "error"
-            ] = "Invalid decode_type specified. Valid decode types are: {}".format(
-                pprint.pformat(valid_decodes)
+            ret["error"] = (
+                "Invalid decode_type specified. Valid decode types are: {}".format(
+                    pprint.pformat(valid_decodes)
+                )
             )
             log.error(ret["error"])
             return ret
