@@ -3,6 +3,7 @@
 Define some generic socket functions for network modules
 """
 
+
 import fnmatch
 import itertools
 import logging
@@ -10,6 +11,7 @@ import os
 import platform
 import random
 import re
+import shutil
 import socket
 import subprocess
 import types
@@ -21,11 +23,10 @@ import salt.utils.files
 import salt.utils.path
 import salt.utils.platform
 import salt.utils.stringutils
-import salt.utils.zeromq
 from salt._compat import ipaddress
 from salt.exceptions import SaltClientError, SaltSystemExit
 from salt.utils.decorators.jinja import jinja_filter
-from salt.utils.versions import LooseVersion
+from salt.utils.versions import Version
 
 try:
     import salt.utils.win_network
@@ -46,18 +47,25 @@ except (ImportError, OSError, AttributeError, TypeError):
     pass
 
 
-_INTERFACES = {}
+class Interfaces:
+    __slots__ = ("interfaces",)
+
+    def __init__(self, interfaces=None):
+        if interfaces is None:
+            interfaces = {}
+        self.interfaces = interfaces
+
+    def __call__(self, *args, **kwargs):
+        if not self.interfaces:
+            self.interfaces = interfaces()
+        return self.interfaces
+
+    def clear(self):
+        self.interfaces = {}
 
 
-def _get_interfaces():
-    """
-    Provide a dict of the connected interfaces and their ip addresses
-    """
-
-    global _INTERFACES
-    if not _INTERFACES:
-        _INTERFACES = interfaces()
-    return _INTERFACES
+_get_interfaces = Interfaces()
+_clear_interfaces = _get_interfaces.clear
 
 
 def sanitize_host(host):
@@ -316,6 +324,16 @@ def is_ipv6(ip_addr):
         return False
 
 
+def is_loopback(ip_addr):
+    """
+    Returns a bool telling if the value passed to it is a loopback address
+    """
+    try:
+        return ipaddress.ip_address(ip_addr).is_loopback
+    except ValueError:
+        return False
+
+
 def is_subnet(cidr):
     """
     Returns a bool telling if the passed string is an IPv4 or IPv6 subnet
@@ -654,8 +672,9 @@ def cidr_to_ipv4_netmask(cidr_bits):
             netmask += "255"
             cidr_bits -= 8
         else:
-            netmask += "{:d}".format(256 - (2 ** (8 - cidr_bits)))
+            netmask += f"{256 - (2 ** (8 - cidr_bits)):d}"
             cidr_bits = 0
+
     return netmask
 
 
@@ -664,8 +683,14 @@ def _number_of_set_bits_to_ipv4_netmask(set_bits):
     Returns an IPv4 netmask from the integer representation of that mask.
 
     Ex. 0xffffff00 -> '255.255.255.0'
+        0xffff6400 -> '255.255.100.0'
     """
-    return cidr_to_ipv4_netmask(_number_of_set_bits(set_bits))
+    # Note: previously used cidr but that is counting number of bits in set_bits
+    # and can lead to wrong netmaks values, for example:
+    # 0xFFFF6400 is 255.255.100.0, 0x64 is 100 decimal
+    # but if convert to cidr first, it gives 19 bits, get 255.255.224.0 - WRONG
+    # leveraging Python ip_address library for different method of conversion
+    return str(ipaddress.ip_address(set_bits))
 
 
 def _number_of_set_bits(x):
@@ -735,12 +760,12 @@ def _interfaces_ip(out):
                 type_, value = tuple(cols[0:2])
                 iflabel = cols[-1:][0]
                 if type_ in ("inet", "inet6"):
+                    ipaddr, netmask, broadcast, scope = parse_network(value, cols)
+                    addr_obj = dict()
                     if "secondary" not in cols:
-                        ipaddr, netmask, broadcast, scope = parse_network(value, cols)
                         if type_ == "inet":
                             if "inet" not in data:
                                 data["inet"] = list()
-                            addr_obj = dict()
                             addr_obj["address"] = ipaddr
                             addr_obj["netmask"] = netmask
                             addr_obj["broadcast"] = broadcast
@@ -749,25 +774,28 @@ def _interfaces_ip(out):
                         elif type_ == "inet6":
                             if "inet6" not in data:
                                 data["inet6"] = list()
-                            addr_obj = dict()
                             addr_obj["address"] = ipaddr
                             addr_obj["prefixlen"] = netmask
                             addr_obj["scope"] = scope
                             data["inet6"].append(addr_obj)
                     else:
-                        if "secondary" not in data:
-                            data["secondary"] = list()
-                        ip_, mask, brd, scp = parse_network(value, cols)
-                        data["secondary"].append(
-                            {
-                                "type": type_,
-                                "address": ip_,
-                                "netmask": mask,
-                                "broadcast": brd,
-                                "label": iflabel,
-                            }
-                        )
-                        del ip_, mask, brd, scp
+                        if type_ == "inet":
+                            if "secondary" not in data:
+                                data["secondary"] = list()
+                            addr_obj["type"] = type_
+                            addr_obj["address"] = ipaddr
+                            addr_obj["netmask"] = netmask
+                            addr_obj["broadcast"] = broadcast
+                            addr_obj["label"] = iflabel
+                            data["secondary"].append(addr_obj)
+                        elif type_ == "inet6":
+                            if "secondary" not in data:
+                                data["secondary"] = list()
+                            addr_obj["type"] = type_
+                            addr_obj["address"] = ipaddr
+                            addr_obj["prefixlen"] = netmask
+                            addr_obj["scope"] = scope
+                            data["secondary"].append(addr_obj)
                 elif type_.startswith("link"):
                     data["hwaddr"] = value
         if iface:
@@ -793,7 +821,8 @@ def _interfaces_ifconfig(out):
         pip = re.compile(r".*?(?:inet addr:|inet [^\d]*)(.*?)\s")
         pip6 = re.compile(".*?(?:inet6 addr: (.*?)/|inet6 )([0-9a-fA-F:]+)")
         pmask6 = re.compile(
-            r".*?(?:inet6 addr: [0-9a-fA-F:]+/(\d+)|prefixlen (\d+))(?: Scope:([a-zA-Z]+)| scopeid (0x[0-9a-fA-F]))?"
+            r".*?(?:inet6 addr: [0-9a-fA-F:]+/(\d+)|prefixlen (\d+))(?:"
+            r" Scope:([a-zA-Z]+)| scopeid (0x[0-9a-fA-F]))?"
         )
     pmask = re.compile(r".*?(?:Mask:|netmask )(?:((?:0x)?[0-9a-fA-F]{8})|([\d\.]+))")
     pupdown = re.compile("UP")
@@ -817,11 +846,7 @@ def _interfaces_ifconfig(out):
                 if salt.utils.platform.is_sunos():
                     expand_mac = []
                     for chunk in data["hwaddr"].split(":"):
-                        expand_mac.append(
-                            "0{}".format(chunk)
-                            if len(chunk) < 2
-                            else "{}".format(chunk)
-                        )
+                        expand_mac.append(f"0{chunk}" if len(chunk) < 2 else f"{chunk}")
                     data["hwaddr"] = ":".join(expand_mac)
             if mip:
                 if "inet" not in data:
@@ -914,7 +939,9 @@ def linux_interfaces():
         )
     elif ifconfig_path:
         cmd = subprocess.Popen(
-            [ifconfig_path, "-a"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
+            [ifconfig_path, "-a"],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
         ).communicate()[0]
         ifaces = _interfaces_ifconfig(salt.utils.stringutils.to_str(cmd))
     return ifaces
@@ -980,7 +1007,7 @@ def _netbsd_interfaces_ifconfig(out):
     return ret
 
 
-def _junos_interfaces_ifconfig(out):
+def _junos_interfaces_ifconfig(out):  # pragma: no cover
     """
     Uses ifconfig to return a dictionary of interfaces with various information
     about each (up/down state, ip address, netmask, and hwaddr)
@@ -1050,7 +1077,7 @@ def _junos_interfaces_ifconfig(out):
     return ret
 
 
-def junos_interfaces():
+def junos_interfaces():  # pragma: no cover
     """
     Obtain interface information for Junos; ifconfig
     output diverged from other BSD variants (Netmask is now part of the
@@ -1058,7 +1085,9 @@ def junos_interfaces():
     """
     ifconfig_path = salt.utils.path.which("ifconfig")
     cmd = subprocess.Popen(
-        [ifconfig_path, "-a"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
+        [ifconfig_path, "-a"],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
     ).communicate()[0]
     return _junos_interfaces_ifconfig(salt.utils.stringutils.to_str(cmd))
 
@@ -1070,12 +1099,14 @@ def netbsd_interfaces():
     address)
     """
     # NetBSD versions prior to 8.0 can still use linux_interfaces()
-    if LooseVersion(os.uname()[2]) < LooseVersion("8.0"):
+    if Version(os.uname()[2]) < Version("8.0"):
         return linux_interfaces()
 
     ifconfig_path = salt.utils.path.which("ifconfig")
     cmd = subprocess.Popen(
-        [ifconfig_path, "-a"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
+        [ifconfig_path, "-a"],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
     ).communicate()[0]
     return _netbsd_interfaces_ifconfig(salt.utils.stringutils.to_str(cmd))
 
@@ -1159,7 +1190,7 @@ def get_net_start(ipaddr, netmask):
     """
     Return the address of the network
     """
-    net = ipaddress.ip_network("{}/{}".format(ipaddr, netmask), strict=False)
+    net = ipaddress.ip_network(f"{ipaddr}/{netmask}", strict=False)
     return str(net.network_address)
 
 
@@ -1181,7 +1212,7 @@ def calc_net(ipaddr, netmask=None):
     (The IP can be any IP inside the subnet)
     """
     if netmask is not None:
-        ipaddr = "{}/{}".format(ipaddr, netmask)
+        ipaddr = f"{ipaddr}/{netmask}"
 
     return str(ipaddress.ip_network(ipaddr, strict=False))
 
@@ -1204,14 +1235,14 @@ def _get_iface_info(iface):
     if iface in iface_info.keys():
         return iface_info, False
     else:
-        error_msg = 'Interface "{}" not in available interfaces: "{}"' "".format(
+        error_msg = 'Interface "{}" not in available interfaces: "{}"'.format(
             iface, '", "'.join(iface_info.keys())
         )
         log.error(error_msg)
         return None, error_msg
 
 
-def _hw_addr_aix(iface):
+def _hw_addr_aix(iface):  # pragma: no cover
     """
     Return the hardware address (a.k.a. MAC address) for a given interface on AIX
     MAC address not available in through interfaces
@@ -1219,7 +1250,9 @@ def _hw_addr_aix(iface):
     cmd = subprocess.Popen(
         ["grep", "Hardware Address"],
         stdin=subprocess.Popen(
-            ["entstat", "-d", iface], stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
+            ["entstat", "-d", iface],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
         ).stdout,
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
@@ -1247,7 +1280,7 @@ def hw_addr(iface):
 
     """
     if salt.utils.platform.is_aix():
-        return _hw_addr_aix
+        return _hw_addr_aix(iface)
 
     iface_info, error = _get_iface_info(iface)
 
@@ -1450,7 +1483,7 @@ def _ip_networks(
         _net = addr.get("netmask" if proto == "inet" else "prefixlen")
         if _ip and _net:
             try:
-                ip_net = ipaddress.ip_network("{}/{}".format(_ip, _net), strict=False)
+                ip_net = ipaddress.ip_network(f"{_ip}/{_net}", strict=False)
             except Exception:  # pylint: disable=broad-except
                 continue
             if not ip_net.is_loopback or include_loopback:
@@ -1559,8 +1592,8 @@ def mac2eui64(mac, prefix=None):
     else:
         try:
             net = ipaddress.ip_network(prefix, strict=False)
-            euil = int("0x{}".format(eui64), 16)
-            return "{}/{}".format(net[euil], net.prefixlen)
+            euil = int(f"0x{eui64}", 16)
+            return f"{net[euil]}/{net.prefixlen}"
         except Exception:  # pylint: disable=broad-except
             return
 
@@ -1685,9 +1718,7 @@ def _netlink_tool_remote_on(port, which_end):
     valid = False
     tcp_end = "dst" if which_end == "remote_port" else "src"
     try:
-        data = subprocess.check_output(
-            ["ss", "-ant", tcp_end, ":{}".format(port)]
-        )  # pylint: disable=minimum-python-version
+        data = subprocess.check_output(["ss", "-ant", tcp_end, f":{port}"])
     except subprocess.CalledProcessError:
         log.error("Failed ss")
         raise
@@ -1702,8 +1733,13 @@ def _netlink_tool_remote_on(port, which_end):
         elif "ESTAB" not in line:
             continue
         chunks = line.split()
+        local_host, local_port = chunks[3].rsplit(":", 1)
         remote_host, remote_port = chunks[4].rsplit(":", 1)
 
+        if which_end == "remote_port" and int(remote_port) != int(port):
+            continue
+        if which_end == "local_port" and int(local_port) != int(port):
+            continue
         remotes.add(remote_host.strip("[]"))
 
     if valid is False:
@@ -1711,7 +1747,7 @@ def _netlink_tool_remote_on(port, which_end):
     return remotes
 
 
-def _sunos_remotes_on(port, which_end):
+def _sunos_remotes_on(port, which_end):  # pragma: no cover
     """
     SunOS specific helper function.
     Returns set of ipv4 host addresses of remote established connections
@@ -1728,9 +1764,7 @@ def _sunos_remotes_on(port, which_end):
     """
     remotes = set()
     try:
-        data = subprocess.check_output(
-            ["netstat", "-f", "inet", "-n"]
-        )  # pylint: disable=minimum-python-version
+        data = subprocess.check_output(["netstat", "-f", "inet", "-n"])
     except subprocess.CalledProcessError:
         log.error("Failed netstat")
         raise
@@ -1751,7 +1785,7 @@ def _sunos_remotes_on(port, which_end):
     return remotes
 
 
-def _freebsd_remotes_on(port, which_end):
+def _freebsd_remotes_on(port, which_end):  # pragma: no cover
     """
     Returns set of ipv4 host addresses of remote established connections
     on local tcp port port.
@@ -1775,8 +1809,8 @@ def _freebsd_remotes_on(port, which_end):
     remotes = set()
 
     try:
-        cmd = salt.utils.args.shlex_split("sockstat -4 -c -p {}".format(port))
-        data = subprocess.check_output(cmd)  # pylint: disable=minimum-python-version
+        cmd = salt.utils.args.shlex_split(f"sockstat -4 -c -p {port}")
+        data = subprocess.check_output(cmd)
     except subprocess.CalledProcessError as ex:
         log.error('Failed "sockstat" with returncode = %s', ex.returncode)
         raise
@@ -1813,7 +1847,7 @@ def _freebsd_remotes_on(port, which_end):
     return remotes
 
 
-def _netbsd_remotes_on(port, which_end):
+def _netbsd_remotes_on(port, which_end):  # pragma: no cover
     """
     Returns set of ipv4 host addresses of remote established connections
     on local tcp port port.
@@ -1837,8 +1871,8 @@ def _netbsd_remotes_on(port, which_end):
     remotes = set()
 
     try:
-        cmd = salt.utils.args.shlex_split("sockstat -4 -c -n -p {}".format(port))
-        data = subprocess.check_output(cmd)  # pylint: disable=minimum-python-version
+        cmd = salt.utils.args.shlex_split(f"sockstat -4 -c -n -p {port}")
+        data = subprocess.check_output(cmd)
     except subprocess.CalledProcessError as ex:
         log.error('Failed "sockstat" with returncode = %s', ex.returncode)
         raise
@@ -1874,7 +1908,7 @@ def _netbsd_remotes_on(port, which_end):
     return remotes
 
 
-def _openbsd_remotes_on(port, which_end):
+def _openbsd_remotes_on(port, which_end):  # pragma: no cover
     """
     OpenBSD specific helper function.
     Returns set of ipv4 host addresses of remote established connections
@@ -1890,14 +1924,12 @@ def _openbsd_remotes_on(port, which_end):
     """
     remotes = set()
     try:
-        data = subprocess.check_output(
-            ["netstat", "-nf", "inet"]
-        )  # pylint: disable=minimum-python-version
-    except subprocess.CalledProcessError:
-        log.error("Failed netstat")
+        data = subprocess.check_output(["netstat", "-nf", "inet"])
+    except subprocess.CalledProcessError as exc:
+        log.error('Failed "netstat" with returncode = %s', exc.returncode)
         raise
 
-    lines = salt.utils.stringutils.to_str(data).split('\n')
+    lines = salt.utils.stringutils.to_str(data).split("\n")
     for line in lines:
         if "ESTABLISHED" not in line:
             continue
@@ -1931,9 +1963,7 @@ def _windows_remotes_on(port, which_end):
     """
     remotes = set()
     try:
-        data = subprocess.check_output(
-            ["netstat", "-n"]
-        )  # pylint: disable=minimum-python-version
+        data = subprocess.check_output(["netstat", "-n"])
     except subprocess.CalledProcessError:
         log.error("Failed netstat")
         raise
@@ -1971,15 +2001,18 @@ def _linux_remotes_on(port, which_end):
 
     """
     remotes = set()
+    lsof_binary = shutil.which("lsof")
+    if lsof_binary is None:
+        return remotes
 
     try:
         data = subprocess.check_output(
             [
-                "lsof",
-                "-iTCP:{:d}".format(port),
+                lsof_binary,
+                f"-iTCP:{port:d}",
                 "-n",
                 "-P",
-            ]  # pylint: disable=minimum-python-version
+            ]
         )
     except subprocess.CalledProcessError as ex:
         if ex.returncode == 1:
@@ -2015,7 +2048,7 @@ def _linux_remotes_on(port, which_end):
     return remotes
 
 
-def _aix_remotes_on(port, which_end):
+def _aix_remotes_on(port, which_end):  # pragma: no cover
     """
     AIX specific helper function.
     Returns set of ipv4 host addresses of remote established connections
@@ -2044,9 +2077,7 @@ def _aix_remotes_on(port, which_end):
     """
     remotes = set()
     try:
-        data = subprocess.check_output(
-            ["netstat", "-f", "inet", "-n"]
-        )  # pylint: disable=minimum-python-version
+        data = subprocess.check_output(["netstat", "-f", "inet", "-n"])
     except subprocess.CalledProcessError:
         log.error("Failed netstat")
         raise
@@ -2139,34 +2170,53 @@ def dns_check(addr, port, safe=False, ipv6=None):
     family = (
         socket.AF_INET6
         if ipv6
-        else socket.AF_INET
-        if ipv6 is False
-        else socket.AF_UNSPEC
+        else socket.AF_INET if ipv6 is False else socket.AF_UNSPEC
     )
+    socket_error = False
     try:
         refresh_dns()
         addrinfo = socket.getaddrinfo(addr, port, family, socket.SOCK_STREAM)
         ip_addrs = _test_addrs(addrinfo, port)
     except TypeError:
-        err = (
-            "Attempt to resolve address '{}' failed. Invalid or unresolveable address"
-        ).format(addr)
-        raise SaltSystemExit(code=42, msg=err)
+        raise SaltSystemExit(
+            code=42,
+            msg=(
+                "Attempt to resolve address '{}' failed. Invalid or unresolveable"
+                " address".format(addr)
+            ),
+        )
     except OSError:
-        pass
+        socket_error = True
+
+    # If ipv6 is set to True, attempt another lookup using the IPv4 family,
+    # just in case we're attempting to lookup an IPv4 IP
+    # as an IPv6 hostname.
+    if socket_error and ipv6:
+        try:
+            refresh_dns()
+            addrinfo = socket.getaddrinfo(
+                addr, port, socket.AF_INET, socket.SOCK_STREAM
+            )
+            ip_addrs = _test_addrs(addrinfo, port)
+        except TypeError:
+            raise SaltSystemExit(
+                code=42,
+                msg=(
+                    "Attempt to resolve address '{}' failed. Invalid or unresolveable"
+                    " address".format(addr)
+                ),
+            )
+        except OSError:
+            error = True
 
     if not ip_addrs:
-        err = ("DNS lookup or connection check of '{}' failed.").format(addr)
+        err = f"DNS lookup or connection check of '{addr}' failed."
         if safe:
-            if salt.log.is_console_configured():
-                # If logging is not configured it also means that either
-                # the master or minion instance calling this hasn't even
-                # started running
-                log.error(err)
+            log.error(err)
             raise SaltClientError()
         raise SaltSystemExit(code=42, msg=err)
 
-    return salt.utils.zeromq.ip_bracket(ip_addrs[0])
+    return ip_bracket(ip_addrs[0])
 
 
 def _test_addrs(addrinfo, port):
@@ -2182,17 +2232,18 @@ def _test_addrs(addrinfo, port):
         if ip_addr in ip_addrs:
             continue
         ip_addrs.append(ip_addr)
-
+        s = None
         try:
             s = socket.socket(ip_family, socket.SOCK_STREAM)
             s.settimeout(2)
             s.connect((ip_addr, port))
-            s.close()
-
             ip_addrs = [ip_addr]
             break
         except OSError:
             pass
+        finally:
+            if s is not None:
+                s.close()
     return ip_addrs
 
 
@@ -2224,25 +2275,18 @@ def parse_host_port(host_port):
                 port = int(_s_.lstrip(":"))
             else:
                 if len(_s_) > 1:
-                    raise ValueError(
-                        'found ambiguous "{}" port in "{}"'.format(_s_, host_port)
-                    )
+                    raise ValueError(f'found ambiguous "{_s_}" port in "{host_port}"')
     else:
         if _s_.count(":") == 1:
             host, _hostport_separator_, port = _s_.partition(":")
             try:
                 port = int(port)
             except ValueError as _e_:
-                log.error(
-                    'host_port "{}" port value "{}" is not an integer.'.format(
-                        host_port, port
-                    )
-                )
-                raise ValueError(
-                    'host_port "{}" port value "{}" is not an integer.'.format(
-                        host_port, port
-                    )
+                errmsg = 'host_port "{}" port value "{}" is not an integer.'.format(
+                    host_port, port
                 )
+                log.error(errmsg)
+                raise ValueError(errmsg)
         else:
             host = _s_
     try:
@@ -2253,7 +2297,7 @@ def parse_host_port(host_port):
         log.debug('"%s" Not an IP address? Assuming it is a hostname.', host)
         if host != sanitize_host(host):
             log.error('bad hostname: "%s"', host)
-            raise ValueError('bad hostname: "{}"'.format(host))
+            raise ValueError(f'bad hostname: "{host}"')
 
     return host, port
 
@@ -2271,9 +2315,8 @@ def filter_by_networks(values, networks):
     {{ grains['ipv4'] | filter_by_networks(networks) }}
     """
 
-    _filter = lambda ips, networks: [
-        ip for ip in ips for net in networks if ipaddress.ip_address(ip) in net
-    ]
+    def _filter(ips, networks):
+        return [ip for ip in ips for net in networks if ipaddress.ip_address(ip) in net]
 
     if networks is not None:
         networks = [ipaddress.ip_network(network) for network in networks]
@@ -2284,6 +2327,37 @@ def filter_by_networks(values, networks):
         elif isinstance(values, Sequence):
             return _filter(values, networks)
         else:
-            raise ValueError("Do not know how to filter a {}".format(type(values)))
+            raise ValueError(f"Do not know how to filter a {type(values)}")
     else:
         return values
+
+
+@jinja_filter("ipwrap")
+def ipwrap(data):
+    """
+    Returns any input (string, list, tuple) as a string or a list with any IPv6 addresses wrapped in square brackets ([]).
+    """
+
+    if isinstance(data, (list, tuple)):
+        ret = []
+        for element in data:
+            if _is_ipv(element, 6, options=None):
+                element = ip_bracket(element)
+            ret.append(element)
+    else:
+        if _is_ipv(data, 6, options=None):
+            data = ip_bracket(data)
+        ret = data
+    return ret
+
+
+def ip_bracket(addr, strip=False):
+    """
+    Ensure IP addresses are URI-compatible - specifically, add brackets
+    around IPv6 literals if they are not already present.
+    """
+    addr = str(addr)
+    addr = addr.lstrip("[")
+    addr = addr.rstrip("]")
+    addr = ipaddress.ip_address(addr)
+    return ("[{}]" if addr.version == 6 and not strip else "{}").format(addr)
