@@ -298,15 +298,26 @@ def verify_env(
         # If acls are enabled, the pki_dir needs to remain readable, this
         # is still secure because the private keys are still only readable
         # by the user running the master
-        if dir_ == pki_dir:
-            smode = stat.S_IMODE(mode.st_mode)
-            if smode != 448 and smode != 488:
-                if os.access(dir_, os.W_OK):
-                    os.chmod(dir_, 448)
-                else:
-                    log.critical(
-                        'Unable to securely set the permissions of "%s".', dir_
-                    )
+        if isinstance(pki_dir, str):
+            if dir_ == pki_dir:
+                smode = stat.S_IMODE(mode.st_mode)
+                if smode != 448 and smode != 488:
+                    if os.access(dir_, os.W_OK):
+                        os.chmod(dir_, 448)
+                    else:
+                        log.critical(
+                            'Unable to securely set the permissions of "%s".', dir_
+                        )
+        else:
+            if dir_ in pki_dir:
+                smode = stat.S_IMODE(mode.st_mode)
+                if smode != 448 and smode != 488:
+                    if os.access(dir_, os.W_OK):
+                        os.chmod(dir_, 448)
+                    else:
+                        log.critical(
+                            'Unable to securely set the permissions of "%s".', dir_
+                        )
 
     if skip_extra is False:
         # Run the extra verification checks
@@ -521,7 +532,7 @@ def clean_path(root, path, subdir=False, realpath=True):
     Pass realpath=False if filesystem links should not be resolved.
     """
     if not os.path.isabs(root):
-        root = os.path.join(os.getcwd(), root)
+        return ""
     root = os.path.normpath(root)
     if not os.path.isabs(path):
         path = os.path.join(root, path)
@@ -545,6 +556,10 @@ def valid_id(opts, id_):
     try:
         if any(x in id_ for x in ("/", "\\", "\0")):
             return False
+        if opts.get("cluster_id", None) is not None:
+            pki_dir = opts["cluster_pki_dir"]
+        else:
+            pki_dir = opts["pki_dir"]
         return bool(clean_path(opts["pki_dir"], id_))
     except (AttributeError, KeyError, TypeError, UnicodeDecodeError):
         return False
