@@ -215,7 +215,7 @@ def ensure_cert_kwargs_compat(kwargs):
         for long_name in long_names:
             if long_name in kwargs:
                 salt.utils.versions.warn_until(
-                    "Potassium",
+                    3009,
                     f"Found {long_name} in keyword args. Please migrate to the short name: {name}",
                 )
                 kwargs[name] = kwargs.pop(long_name)
@@ -224,7 +224,7 @@ def ensure_cert_kwargs_compat(kwargs):
         for long_name in long_names:
             if long_name in kwargs:
                 salt.utils.versions.warn_until(
-                    "Potassium",
+                    3009,
                     f"Found {long_name} in keyword args. Please migrate to the short name: {extname}",
                 )
                 kwargs[extname] = kwargs.pop(long_name)
@@ -587,7 +587,7 @@ def merge_signing_policy(policy, kwargs):
         for long_name in long_names:
             if long_name in kwargs:
                 salt.utils.versions.warn_until(
-                    "Potassium",
+                    3009,
                     f"Found {long_name} in keyword args. Please migrate to the short name: {name}",
                 )
                 kwargs[name] = kwargs.pop(long_name)
@@ -597,7 +597,7 @@ def merge_signing_policy(policy, kwargs):
         for long_name in long_names:
             if long_name in kwargs:
                 salt.utils.versions.warn_until(
-                    "Potassium",
+                    3009,
                     f"Found {long_name} in keyword args. Please migrate to the short name: {extname}",
                 )
                 kwargs[extname] = kwargs.pop(long_name)
