@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Utility functions for zfs
 
@@ -13,9 +12,6 @@ These functions are for dealing with type conversion and basic execution
 
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import math
 import os
@@ -23,11 +19,6 @@ import re
 from numbers import Number
 
 import salt.modules.cmdmod
-
-# Import 3rd-party libs
-from salt.ext.six.moves import zip
-
-# Import salt libs
 from salt.utils.decorators import memoize as real_memoize
 from salt.utils.odict import OrderedDict
 from salt.utils.stringutils import to_num as str_to_num
@@ -177,9 +168,9 @@ def _auto(direction, name, value, source="auto", convert_to_human=True):
 
     # NOTE: convert
     if value_type == "size" and direction == "to":
-        return globals()["{}_{}".format(direction, value_type)](value, convert_to_human)
+        return globals()[f"{direction}_{value_type}"](value, convert_to_human)
 
-    return globals()["{}_{}".format(direction, value_type)](value)
+    return globals()[f"{direction}_{value_type}"](value)
 
 
 @real_memoize
@@ -343,7 +334,7 @@ def has_feature_flags():
     """
     # get man location
     man = salt.utils.path.which("man")
-    return _check_retcode("{man} zpool-features".format(man=man)) if man else False
+    return _check_retcode(f"{man} zpool-features") if man else False
 
 
 @real_memoize
@@ -551,10 +542,16 @@ def to_size(value, convert_to_human=True):
         #       see libzfs implementation linked above
         v_size_float = float(value) / v_multiplier
         if v_size_float == int(v_size_float):
-            value = "{:.0f}{}".format(v_size_float, zfs_size[v_power - 1],)
+            value = "{:.0f}{}".format(
+                v_size_float,
+                zfs_size[v_power - 1],
+            )
         else:
             for v_precision in ["{:.2f}{}", "{:.1f}{}", "{:.0f}{}"]:
-                v_size = v_precision.format(v_size_float, zfs_size[v_power - 1],)
+                v_size = v_precision.format(
+                    v_size_float,
+                    zfs_size[v_power - 1],
+                )
                 if len(v_size) <= 5:
                     value = v_size
                     break
@@ -757,6 +754,3 @@ def parse_command_result(res, label=None):
             del ret["error"]
 
     return ret
-
-
-# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
